## Comparator to create to_delete.txt for shop updates

### Example
```php
namespace Gambio\Dragger;

use Gambio\Dragger\PackageComparator\DeletedFilesComparator;
use SebastianBergmann\Timer\Timer;

require_once './vendor/autoload.php';

Timer::start();

// define source and compare packages
$sourcePackage   = __DIR__ . '/../../Dokumente/Gx_Vollversion/v4_1_1_0_rc1/src';
$comparePackages = [
    __DIR__ . '/../../Dokumente/Gx_Vollversion/v4_0_0_1/src',
    __DIR__ . '/../../Dokumente/Gx_Betas/F_v4_1_1_0_beta1/src',
    __DIR__ . '/../../Dokumente/Gx_Betas/F_v4_1_1_0_beta2/src',
    __DIR__ . '/../../Dokumente/Gx_Betas/F_v4_1_1_0_beta3/src',
];
// directories can be excluded from comparison
$excludes        = [
    './version_info'
];

// create a comparator and enable verbosity
$comparator = DeletedFilesComparator::create($sourcePackage, $comparePackages);
$comparator->verbose();

// compare packages. if a package not exists, an exception is thrown
try {
    $comparator->compare($excludes);
} catch (PackageComparator\Exceptions\PathNotFoundException $e) {
    echo "Error:\n{$e->getMessage()}\n";
    exit(1);
}

// manipulates the result data by trimming the beginning "./" from elements
$comparator->manipulateComparison(
    static function (string $path): string {
        return ltrim($path, './');
    }
);
// saves the result to disk
$comparator->saveComparison(__DIR__ . '/sample_to_delete.txt');

function memoryUsage()
{
    $size = memory_get_usage(true);
    $unit = ['B', 'KB', 'MB', 'GB', 'TB', 'PB'];
    
    return @round($size / (1024 ** ($i = floor(log($size, 1024)))), 2) . ' ' . $unit[$i];
}

// some additional script execution information
$memory = memoryUsage();
$time   = Timer::timeSinceStartOfRequest();

echo "Used memory: $memory\n";
echo "Time: $time\n";
```
