<?php
/* --------------------------------------------------------------
 ApiClient.php 2019-07-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike;

use Gambio\Dragger\ApiTesting\SwaggerLike\Configuration\RequestConfiguration;
use Gambio\Dragger\ApiTesting\SwaggerLike\Exception\RequestFailedException;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Exception\RequestException;
use Psr\Http\Message\ResponseInterface;

/**
 * Class ApiClient
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike
 */
class ApiClient
{
    /**
     * @var Client
     */
    private $client;
    
    
    /**
     * ApiClient constructor.
     *
     * @param Client $client
     */
    private function __construct(Client $client)
    {
        $this->client = $client;
    }
    
    
    /**
     * Factory method to create API client from request configuration.
     *
     * @param RequestConfiguration $configuration
     *
     * @return ApiClient
     */
    public static function fromRequestConfig(RequestConfiguration $configuration): self
    {
        $config = [
            'base_uri' => $configuration->baseUrl(),
            'auth'     => [$configuration->user(), $configuration->password()]
        ];
        $client = new Client($config);
        
        return new static($client);
    }
    
    
    /**
     * Requests the the given url and raise and request failed exception in case of an error.
     *
     * @param string $method
     * @param string $uri
     * @param array  $options
     *
     * @return ResponseInterface
     * @throws RequestFailedException
     */
    public function requestOrFail(string $method, string $uri, array $options = []): ResponseInterface
    {
        try {
            return $this->client->request($method, $uri, $options);
        } catch (RequestException $e) {
            /** @noinspection NullPointerExceptionInspection */
            $message = <<<MSG
Request failed.
Reason: {$e->getResponse()->getReasonPhrase()}
Message: {$e->getMessage()}
Response: {$e->getResponse()->getBody()->getContents()}
MSG;
            throw new RequestFailedException($message);
        } catch (GuzzleException $e) {
            $message = <<<MSG
Request failed.
Message: {$e->getMessage()}
MSG;
            
            throw new RequestFailedException($message);
        }
    }
}