<?php
/* --------------------------------------------------------------
 TestConfiguration.php 2019-08-09
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Configuration;

use Webmozart\Assert\Assert;

/**
 * Class TestConfiguration
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Configuration
 */
class TestConfiguration
{
    /**
     * @var string
     */
    private $sutFile;
    
    /**
     * @var array
     */
    private $urlPlaceholders;
    
    /**
     * @var string
     */
    private $initialFixture;
    
    
    /**
     * TestConfiguration constructor.
     *
     * @param string      $sutFile
     * @param array       $urlPlaceholders
     * @param string|null $initialFixture
     */
    private function __construct(string $sutFile, array $urlPlaceholders, string $initialFixture = null)
    {
        Assert::file($sutFile);
        if (null !== $initialFixture) {
            Assert::file($initialFixture);
        }
        
        $this->sutFile         = $sutFile;
        $this->urlPlaceholders = $urlPlaceholders;
        $this->initialFixture  = $initialFixture;
    }
    
    
    /**
     * Factory method for TestConfiguration.
     *
     * @param string      $sutFile
     * @param array       $urlPlaceholders
     * @param string|null $initialFixture
     *
     * @return TestConfiguration
     */
    public static function create(string $sutFile, array $urlPlaceholders, string $initialFixture = null) : self
    {
        return new static($sutFile, $urlPlaceholders, $initialFixture);
    }
    
    
    /**
     * @return string
     */
    public function sutFile() : string
    {
        return $this->sutFile;
    }
    
    
    /**
     * @return array
     */
    public function urlPlaceholders() : array
    {
        return $this->urlPlaceholders;
    }
    
    
    /**
     * @return string|null
     */
    public function initialFixture() : ?string
    {
        return $this->initialFixture;
    }
}