<?php
/* --------------------------------------------------------------
 ResponseMatchSchema.php 2019-07-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Constraint;

use Gambio\Dragger\ApiTesting\SwaggerLike\Failure\Failures;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\Schema;
use Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Schema\PropertiesValidator;
use Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Schema\RequiredValidator;
use Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Schema\ScalarPropertyValidator;
use Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Schema\SchemaValidator;
use PHPUnit\Framework\Constraint\Constraint;
use function is_array;

/**
 * Class ResponseMatchSchema
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Verify
 */
class ResponseMatchSchema extends Constraint
{
    /**
     * @var Schema
     */
    private $schema;
    
    /**
     * @var SchemaValidator
     */
    private $validator;
    
    
    /**
     * ResponseMatchSchema constructor.
     *
     * @param Schema $schema
     */
    public function __construct(Schema $schema)
    {
        parent::__construct();
        $this->schema = $schema;
        
        $failures        = Failures::create();
        $reqValidator    = new RequiredValidator($failures);
        $scalarValidator = new ScalarPropertyValidator($failures);
        $propValidator   = new PropertiesValidator($scalarValidator, $reqValidator, $failures);
        
        $this->validator = new SchemaValidator($propValidator, $reqValidator, $failures);
    }
    
    
    /**
     * Evaluates the constraint for parameter $other. Returns true if the constraint is met,
     * so when $other (the API Response-Body) matches the Schema ($this->schema) and false otherwise.
     *
     * @param mixed $other
     *
     * @return bool
     */
    protected function matches($other) : bool
    {
        if (!is_array($other)) {
            return false;
        }
        
        return $this->validator->validate($this->schema, $other);
    }
    
    
    /**
     * Returns a string representation of constraint.
     */
    public function toString() : string
    {
        return 'matches schema';
    }
    
    
    /**
     * Returns additional failure description, which is a string representation
     * of all failed assertions on schema validation.
     *
     * @param mixed $other
     *
     * @return string
     */
    protected function additionalFailureDescription($other) : string
    {
        return $this->validator->failures();
    }
}