<?php
/* --------------------------------------------------------------
 IdentifierChanger.php 2019-08-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Faker;

use Webmozart\Assert\Assert;
use function count;

/**
 * Class IdentifierChanger
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Faker
 */
class IdentifierChanger
{
    /**
     * Changes the identifier of a single data set.
     *
     * @param array  $entity
     * @param string $identifier
     * @param        $newId
     *
     * @return array
     */
    public function changeEntity(array $entity, string $identifier, $newId) : array
    {
        Assert::keyExists($entity, $identifier);
        
        $entity[$identifier] = $newId;
        
        return $entity;
    }
    
    
    /**
     * Changes the identifiers for a list of data sets.
     *
     * @param array  $entityList
     * @param string $identifier
     * @param array  $newIds
     *
     * @return array
     */
    public function changeList(array $entityList, string $identifier, array $newIds) : array
    {
        Assert::eq(count($entityList), count($newIds));
        
        foreach ($newIds as $index => $newId) {
            Assert::keyExists($entityList, $index);
            Assert::keyExists($entityList[$index], $identifier);
            $entityList[$index][$identifier] = $newId;
        }
        
        return $entityList;
    }
}