<?php
/* --------------------------------------------------------------
 PutRequestFaker.php 2019-08-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Faker;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\Schema;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\SchemaList;
use function count;

/**
 * Class PutRequestFaker
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Faker
 */
class PutRequestFaker
{
    /**
     * @var SchemaDataFaker
     */
    private $schemaFaker;
    
    /**
     * @var IdentifierChanger
     */
    private $idChanger;
    
    
    /**
     * PutRequestFaker constructor.
     *
     * @param SchemaDataFaker   $schemaFaker
     * @param IdentifierChanger $idChanger
     */
    public function __construct(SchemaDataFaker $schemaFaker, IdentifierChanger $idChanger)
    {
        $this->schemaFaker = $schemaFaker;
        $this->idChanger   = $idChanger;
    }
    
    
    /**
     * Fakes schema data.
     *
     * @param Schema $schema
     * @param string $identifier
     * @param mixed  ...$newIds
     *
     * @return array
     */
    public function fake(Schema $schema, string $identifier, ...$newIds): array
    {
        if ($schema instanceof SchemaList) {
            return $this->fakeList($schema, $identifier, $newIds);
        }
        
        return $this->fakeEntity($schema, $identifier, ...$newIds);
    }
    
    
    /**
     * Fakes data set for a single entity.
     *
     * @param Schema $schema
     * @param string $identifier
     * @param mixed  $newId
     *
     * @return array
     */
    public function fakeEntity(Schema $schema, string $identifier, $newId): array
    {
        $data = $this->schemaFaker->fake($schema);
        
        return $this->idChanger->changeEntity($data, $identifier, $newId);
    }
    
    
    /**
     * Fakes data for a list of entities.
     *
     * @param SchemaList $schemaList
     * @param string     $identifier
     * @param array      $newIds
     *
     * @return array
     */
    public function fakeList(SchemaList $schemaList, string $identifier, array $newIds): array
    {
        $nbDataSets = count($newIds);
        $data       = $this->schemaFaker->fake($schemaList, $nbDataSets);
        
        return $this->idChanger->changeList($data, $identifier, $newIds);
    }
    
    
    /**
     * Uses given column names to fake a date time value.
     *
     * @param array $dateColumns
     */
    public function useDateColumns(array $dateColumns): void
    {
        $this->schemaFaker->useDateColumns($dateColumns);
    }
}