<?php
/* --------------------------------------------------------------
 StringFaker.php 2019-08-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Faker;

use Faker\Generator;
use function array_merge;
use function array_unique;
use function in_array;

/**
 * Class StringFaker
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Faker
 */
class StringFaker
{
    /**
     * @var Generator
     */
    private $faker;
    
    /**
     * @var array
     */
    private $dateColumns = ['lastModified', 'expiresAt'];
    
    
    /**
     * StringFaker constructor.
     *
     * @param Generator $faker
     */
    public function __construct(Generator $faker)
    {
        $this->faker = $faker;
    }
    
    
    /**
     * Fakes a string value.
     * If the name is associated with a date, a datetime string will be returned.
     *
     * @param string|null $name
     *
     * @return string
     */
    public function fake(string $name = null): string
    {
        if (!$name) {
            return $this->faker->word;
        }
        
        if (stripos($name, 'date') === 0 || in_array($name, $this->dateColumns, true)) {
            return $this->faker->dateTime->format('Y-m-d H:i:s');
        }
        
        return $this->faker->word;
    }
    
    
    /**
     * Uses given column names to fake a date time value.
     *
     * @param array $dateColumns
     */
    public function useDateColumns(array $dateColumns): void
    {
        $this->dateColumns = array_merge($this->dateColumns, $dateColumns);
        $this->dateColumns = array_unique($this->dateColumns);
    }
}