<?php
/* --------------------------------------------------------------
 Parameters.php 2019-07-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\Parameter;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Parameter\BodyParameter;
use InvalidArgumentException;

/**
 * Class Parameters
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection
 */
class Parameters
{
    /**
     * @var Parameter[]
     */
    private $items = [];
    
    /**
     * @var BodyParameter
     */
    private $bodyParam;
    
    
    /**
     * Factory method of parameters
     *
     * @return Parameters
     */
    public static function create() : self
    {
        return new static();
    }
    
    
    /**
     * Adds new collection item.
     *
     * @param Parameter $parameter
     */
    public function add(Parameter $parameter) : void
    {
        if ($parameter instanceof BodyParameter) {
            if (null !== $this->bodyParam) {
                throw new InvalidArgumentException(
                    'Body param already set! Only one body param in each schema is allowed.'
                );
            }
            $this->bodyParam = $parameter;
        }
        
        $this->items[$parameter->name()] = $parameter;
    }
    
    
    /**
     * @return array
     */
    public function items() : array
    {
        return $this->items;
    }
    
    
    /**
     * Returns body parameter from param collection, if available.
     *
     * @return BodyParameter|null
     */
    public function bodyParam() : ?BodyParameter
    {
        return $this->bodyParam;
    }
}