<?php
/* --------------------------------------------------------------
 Definition.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection\Properties;

/**
 * Class Definition
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Definition
 */
class Definition
{
    /**
     * @var string
     */
    private $title;
    
    /**
     * @var array
     */
    private $required;
    
    /**
     * @var Properties
     */
    private $properties;
    
    
    /**
     * Definition constructor.
     *
     * @param string     $title
     * @param Properties $properties
     * @param array      $required
     */
    private function __construct(string $title, Properties $properties, array $required = [])
    {
        $this->title      = $title;
        $this->required   = $required;
        $this->properties = $properties;
    }
    
    
    /**
     * Factory method for Definition.
     *
     * @param string     $title
     * @param Properties $properties
     * @param array      $required
     *
     * @return Definition
     */
    public static function create(string $title, Properties $properties, array $required = []) : self
    {
        return new static($title, $properties, $required);
    }
    
    
    /**
     * @return string
     */
    public function title() : string
    {
        return $this->title;
    }
    
    
    /**
     * @return array
     */
    public function required() : array
    {
        return $this->required;
    }
    
    
    /**
     * @return Properties
     */
    public function properties() : Properties
    {
        return $this->properties;
    }
}