<?php
/* --------------------------------------------------------------
 SimpleFactory.php 2019-08-06
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Factory;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection\Parameters;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection\Responses;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\SchemaReference as SchemaReferenceInterface;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Endpoint;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Reference\SchemaListReference;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Reference\SchemaReference;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Response;

/**
 * Class SimpleFactory
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Factory
 *
 * @codeCoverageIgnore (Only simple factory methods, so actually no need for testing).
 */
class SimpleFactory
{
    /**
     * Creates a responses collection.
     *
     * @return Responses
     */
    public function createResponses() : Responses
    {
        return Responses::create();
    }
    
    
    /**
     * Creates a response model.
     *
     * @param int                      $statusCode
     * @param SchemaReferenceInterface $reference
     *
     * @return Response
     */
    public function createResponse(int $statusCode, SchemaReferenceInterface $reference) : Response
    {
        return Response::create($statusCode, $reference);
    }
    
    
    /**
     * Creates an endpoint model.
     *
     * @param string     $path
     * @param string     $method
     * @param Parameters $parameters
     * @param Responses  $responses
     *
     * @return Endpoint
     */
    public function createEndpoint(
        string $path,
        string $method,
        Parameters $parameters,
        Responses $responses
    ) : Endpoint {
        return Endpoint::create($path, $method, $parameters, $responses);
    }
    
    
    /**
     * Creates a schema model.
     *
     * @param array $data
     *
     * @return SchemaReferenceInterface
     */
    public function createSchemaReference(array $data) : SchemaReferenceInterface
    {
        if (array_key_exists('items', $data)) {
            return SchemaListReference::fromArray($data);
        }
        
        return SchemaReference::fromArray($data);
    }
}