<?php
/* --------------------------------------------------------------
 ParameterIn.php 2019-08-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Parameter;

/**
 * Class ParameterIn
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Parameter
 *
 * Enum type for parameter in attribute. Can be either "path" or "body".
 */
final class ParameterIn
{
    public const IN_PATH = 'path';
    public const IN_BODY = 'body';
    
    private $type;
    
    
    private function __construct()
    {
    }
    
    
    /**
     * Returns a parameter in enum of type "body".
     * Can be compared with: (string)$paramIn === ParameterIn::IN_BODY.
     *
     * @return ParameterIn
     */
    public static function body() : self
    {
        return self::create(self::IN_BODY);
    }
    
    
    /**
     * Returns a parameter in enum of type "path".
     * Can be compared with: (string)$paramIn === ParameterIn::IN_PATH.
     *
     * @return ParameterIn
     */
    public static function path() : self
    {
        return self::create(self::IN_PATH);
    }
    
    
    /**
     * Helper factory method to create instances with specific type.
     *
     * @param string $type
     *
     * @return ParameterIn
     */
    private static function create(string $type) : self
    {
        $enum       = new static();
        $enum->type = $type;
        
        return $enum;
    }
    
    
    /**
     * Magic method to convert enum to string.
     *
     * @return string
     */
    public function __toString() : string
    {
        return $this->type;
    }
}