<?php
/* --------------------------------------------------------------
 ObjectProperty.php 2019-07-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection\Properties;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\HasRequired;

/**
 * Class ObjectProperty
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property
 */
class ObjectProperty extends AbstractProperty implements HasRequired
{
    /**
     * @var string
     */
    private $name;
    
    /**
     * @var Properties
     */
    private $properties;
    
    /**
     * @var array
     */
    private $required;
    
    /**
     * @var bool
     */
    private $nullable;
    
    
    /**
     * ObjectProperty constructor.
     *
     * @param string     $name
     * @param Properties $properties
     * @param array      $required
     * @param bool       $nullable
     */
    private function __construct(string $name, Properties $properties, array $required = [], bool $nullable = false)
    {
        $this->name       = $name;
        $this->properties = $properties;
        $this->required   = $required;
        $this->nullable   = $nullable;
    }
    
    
    /**
     * Factory method for ObjectProperty.
     *
     * @param string     $name
     * @param Properties $properties
     * @param array      $required
     * @param bool       $nullable
     *
     * @return ObjectProperty
     */
    public static function create(
        string $name,
        Properties $properties,
        array $required = [],
        bool $nullable = false
    ) : self {
        return new static($name, $properties, $required, $nullable);
    }
    
    
    /**
     * @return string
     */
    public function name() : string
    {
        return $this->name;
    }
    
    
    /**
     * @return Properties
     */
    public function properties() : Properties
    {
        return $this->properties;
    }
    
    
    /**
     * @return array
     */
    public function required() : array
    {
        return $this->required;
    }
    
    
    /**
     * @return bool
     */
    public function isNullable() : bool
    {
        return $this->nullable;
    }
}