<?php
/* --------------------------------------------------------------
 ReferencedProperty.php 2019-07-04
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\PropertyReference;

/**
 * Class ReferencedProperty
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property
 */
class ReferencedProperty extends AbstractProperty
{
    /**
     * @var string
     */
    private $name;
    
    /**
     * @var PropertyReference
     */
    private $reference;
    
    /**
     * @var bool
     */
    private $nullable;
    
    
    /**
     * ReferencedProperty constructor.
     *
     * @param string            $name
     * @param PropertyReference $reference
     * @param bool              $nullable
     */
    private function __construct(string $name, PropertyReference $reference, bool $nullable)
    {
        $this->name      = $name;
        $this->reference = $reference;
        $this->nullable  = $nullable;
    }
    
    
    /**
     * Factory method for ReferencedProperty.
     *
     * @param string            $name
     * @param PropertyReference $reference
     * @param bool              $nullable
     *
     * @return ReferencedProperty
     */
    public static function create(string $name, PropertyReference $reference, bool $nullable = false) : self
    {
        return new static($name, $reference, $nullable);
    }
    
    
    /**
     * @return string
     */
    public function name() : string
    {
        return $this->name;
    }
    
    
    /**
     * @return PropertyReference
     */
    public function reference() : PropertyReference
    {
        return $this->reference;
    }
    
    
    /**
     * @return bool
     */
    public function isNullable() : bool
    {
        return $this->nullable;
    }
}