<?php
/* --------------------------------------------------------------
 ScalarProperty.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\TypedAndNamed;

/**
 * Class ScalarProperty
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Definition
 */
class ScalarProperty extends AbstractProperty implements TypedAndNamed
{
    /**
     * @var string
     */
    private $name;
    
    /**
     * @var string
     */
    private $type;
    
    /**
     * @var bool
     */
    private $nullable;
    
    
    /**
     * ScalarProperty constructor.
     *
     * @param string $name
     * @param string $type
     * @param bool   $nullable
     */
    private function __construct(string $name, string $type, bool $nullable = false)
    {
        $this->name     = $name;
        $this->type     = $type;
        $this->nullable = $nullable;
    }
    
    
    /**
     * Factory method for ScalarProperty.
     *
     * @param string $name
     * @param string $type
     * @param bool   $nullable
     *
     * @return ScalarProperty
     */
    public static function create(string $name, string $type, bool $nullable = false) : self
    {
        return new static($name, $type, $nullable);
    }
    
    
    /**
     * @return string
     */
    public function name() : string
    {
        return $this->name;
    }
    
    
    /**
     * @return string
     */
    public function type() : string
    {
        return $this->type;
    }
    
    
    /**
     * @return bool
     */
    public function isNullable() : bool
    {
        return $this->nullable;
    }
}