<?php
/* --------------------------------------------------------------
 Schema.php 2019-07-04
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Schema;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection\Properties;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\HasRequired;

/**
 * Class Schema
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Model\Schema
 */
class Schema implements \Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\Schema, HasRequired
{
    /**
     * @var string
     */
    private $title;
    
    /**
     * @var Properties
     */
    private $properties;
    
    /**
     * @var array
     */
    private $required;
    
    
    /**
     * Schema constructor.
     *
     * @param string     $title
     * @param Properties $properties
     * @param array      $required
     */
    private function __construct(string $title, Properties $properties, array $required = [])
    {
        $this->title      = $title;
        $this->properties = $properties;
        $this->required   = $required;
    }
    
    
    /**
     * Factory method for Schema.
     *
     * @param string     $title
     * @param Properties $properties
     * @param array      $required
     *
     * @return Schema
     */
    public static function create(string $title, Properties $properties, array $required = []) : self
    {
        return new static($title, $properties, $required);
    }
    
    
    /**
     * @return string
     */
    public function name() : string
    {
        return $this->title;
    }
    
    
    /**
     * @return Properties
     */
    public function properties() : Properties
    {
        return $this->properties;
    }
    
    
    /**
     * @return array
     */
    public function required() : array
    {
        return $this->required;
    }
}