<?php
/* --------------------------------------------------------------
 RestDocRepository.php 2019-07-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Repository;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\Schema;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Endpoint;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Reference\SchemaListReference;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Response;
use Gambio\Dragger\ApiTesting\SwaggerLike\Resolver\ReferenceParser;
use Symfony\Component\Yaml\Parser;

/**
 * Class RestDocRepository
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Repository
 */
class RestDocRepository implements \Gambio\Dragger\ApiTesting\SwaggerLike\Model\RestDocRepository
{
    /**
     * @var Parser
     */
    private $yamlParser;
    
    /**
     * @var EndpointMapper
     */
    private $endpointMapper;
    
    /**
     * @var SchemaMapper
     */
    private $schemaMapper;
    
    /**
     * @var ReferenceParser
     */
    private $refParser;
    
    
    /**
     * RestDocRepository constructor.
     *
     * @param Parser          $reader
     * @param EndpointMapper  $endpointMapper
     * @param SchemaMapper    $schemaMapper
     * @param ReferenceParser $referenceParser
     */
    public function __construct(
        Parser $reader,
        EndpointMapper $endpointMapper,
        SchemaMapper $schemaMapper,
        ReferenceParser $referenceParser
    ) {
        $this->yamlParser     = $reader;
        $this->endpointMapper = $endpointMapper;
        $this->schemaMapper   = $schemaMapper;
        $this->refParser      = $referenceParser;
    }
    
    
    /**
     * Returns the endpoint documentation.
     *
     * @param string $filepath
     *
     * @return Endpoint
     */
    public function getEndpointDoc(string $filepath) : Endpoint
    {
        $docsData = $this->yamlParser->parseFile($filepath);
        
        return $this->endpointMapper->map($docsData);
    }
    
    
    /**
     * Resolves the schema of the response.
     *
     * @param Response $response
     *
     * @return Schema
     */
    public function resolveResponseSchema(Response $response) : Schema
    {
        $ref  = $response->reference();
        $data = $this->refParser->parse($ref);
        
        if ($ref instanceof SchemaListReference) {
            return $this->schemaMapper->mapList($data);
        }
        
        return $this->schemaMapper->map($data);
    }
}