<?php
/* --------------------------------------------------------------
 SimpleEventListener.php 2019-08-23
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike;

use Closure;
use function array_key_exists;

/**
 * Class SimpleEventListener
 * @package Gambio\Dragger\ApiTesting\SwaggerLike
 */
class SimpleEventListener
{
    /**
     * @var array
     */
    private static $events = [];
    
    
    /**
     * Listens for new event called $name.
     * Triggers closure on event.
     *
     * @param string  $name
     * @param Closure $callable
     */
    public static function listen(string $name, Closure $callable) : void
    {
        static::$events[$name][] = $callable;
    }
    
    
    /**
     * Notifies listener to trigger event.
     *
     * @param string $name
     * @param mixed  ...$arguments
     */
    public static function trigger(string $name, ...$arguments) : void
    {
        if (array_key_exists($name, static::$events)) {
            foreach (static::$events[$name] as $callable) {
                $callable(...$arguments);
            }
        }
    }
    
    
    /**
     * Removes listener by name.
     *
     * @param string $name
     */
    public static function remove(string $name) : void
    {
        if (array_key_exists($name, static::$events)) {
            static::$events[$name] = [];
        }
    }
}