<?php
/* --------------------------------------------------------------
 GetTestCase.php 2019-07-15
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\TestCase;

use Gambio\Dragger\ApiTesting\SwaggerLike\AssertApi;
use Gambio\Dragger\ApiTesting\SwaggerLike\Configuration\TestConfiguration;
use Gambio\Dragger\ApiTesting\SwaggerLike\Exception\RequestFailedException;
use Gambio\Dragger\ApiTesting\SwaggerLike\SimpleEventListener;
use function json_decode;

/**
 * Class GetTestCase
 *
 * @package Gambio\Dragger\ApiTesting\SwaggerLike
 */
abstract class GetTestCase extends AbstractApiTestCase
{
    /**
     * Asserts that response of api request match defined schema.
     * Performs an http request and validates the responded status code and data.
     *
     * @param TestConfiguration $configuration
     */
    protected function assertResponsesMatchesSchema(TestConfiguration $configuration) : void
    {
        $this->setupFixture();
        $endpoint = $this->endpointFrom($configuration->sutFile());
        $url      = $this->resolveEndpointUrl($endpoint, $configuration->urlPlaceholders());
        
        $this->setupResponseListener($endpoint);
        
        try {
            $actualResponse = $this->apiClient->requestOrFail($endpoint->method(), $url);
            
            SimpleEventListener::trigger(self::EVENT_RECEIVED_RESPONSE, $actualResponse);
            SimpleEventListener::remove(self::EVENT_RECEIVED_RESPONSE);
        } catch (RequestFailedException $e) {
            $this->fail($e->getMessage());
        }
    }
}