<?php
/* --------------------------------------------------------------
 PutTestCase.php 2019-08-21
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\TestCase;

use Gambio\Dragger\ApiTesting\SwaggerLike\AssertApi;
use Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Put\PutTestVerification;
use RuntimeException;
use function get_class;
use function str_replace;

/**
 * Class PutTestCase
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\TestCase
 */
abstract class PutTestCase extends AbstractApiTestCase
{
    /**
     * Asserts that put request matches test verification.
     *
     * @param PutTestVerification $verification
     */
    public function assertPutRequest(PutTestVerification $verification): void
    {
        $this->setupFixture();
        $this->setupResponseListener($verification->endpoint());
        
        AssertApi::assertPutRequest($verification);
    }
    
    
    /**
     * @return string|null
     */
    protected function initialFixture(): ?string
    {
        $current = get_class($this);
        $method  = __METHOD__;
        $caller  = str_replace(__CLASS__, $current, $method);
        
        $message = <<<MSG
Override {$method}
The method body of {$caller} must override the parents method to setup initial data for the test.
Put request usually depends on data, so the fixture is required!
MSG;
        
        throw new RuntimeException($message);
    }
}