<?php
/* --------------------------------------------------------------
 EndpointUrlResolver.php 2019-08-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Traits;

use Gambio\Dragger\ApiTesting\SwaggerLike\Failure\Failures;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Endpoint;
use Gambio\Dragger\ApiTesting\SwaggerLike\Validator\PathParametersValidator;
use UnexpectedValueException;
use function ltrim;

/**
 * Trait EndpointUrlResolver
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Traits
 */
trait EndpointUrlResolver
{
    /**
     * Resolves endpoint url.
     * Validates placeholders, if available.
     *
     * @param Endpoint $endpoint
     * @param array    $placeholders
     *
     * @return string
     */
    public function resolveEndpointUrl(Endpoint $endpoint, array $placeholders = []) : string
    {
        $validator = PathParametersValidator::create(Failures::create());
        if (!$validator->validate($endpoint->parameters(), $placeholders)) {
            throw new UnexpectedValueException($validator->failures());
        }
        $wrapInBraces = static function (string $toWrap) {
            return '{' . $toWrap . '}';
        };
        
        $search = array_map($wrapInBraces, array_keys($placeholders));
        
        // trim left slash, because otherwise guzzle will interpret this as whole path
        return ltrim(str_replace($search, $placeholders, $endpoint->path()), '/');
    }
}