<?php
/* --------------------------------------------------------------
 NothingRemovedStrategy.php 2019-08-28
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Delete;

use Gambio\Dragger\ApiTesting\SwaggerLike\Contracts\Verification\DeleteValidationStrategy;
use Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Delete\Expect;

/**
 * Class NothingRemovedStrategy
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Delete
 */
class ExistsStrategy extends AbstractDeleteStrategy implements DeleteValidationStrategy
{
    /**
     * Validates the internal data.
     *
     * @param Expect[] $expectations
     *
     * @return bool
     */
    public function validate(Expect ...$expectations) : bool
    {
        $errMsgHead = 'Data set was removed.';
        $this->checkDataSetsExist(true, $errMsgHead, ...$expectations);
        
        return !$this->failures->failed();
    }
    
    
    /**
     * Setup for validation (pre-request).
     * Should be used for example to count data sets before the request happen.
     *
     * @param Expect[] $expectations
     */
    public function setup(Expect ...$expectations) : void
    {
        $this->failures->reset();
        $errMsgHead = 'Unable to perform check, because initial data set was not found.';
        $this->checkDataSetsExist(true, $errMsgHead, ...$expectations);
    }
}