<?php
/* --------------------------------------------------------------
 AbstractPutStrategy.php 2019-09-04
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Put;

use Doctrine\DBAL\Connection;
use Gambio\Dragger\ApiTesting\SwaggerLike\Failure\Failures;

/**
 * Class AbstractPutStrategy
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Put
 */
abstract class AbstractPutStrategy
{
    /**
     * @var Connection
     */
    protected $connection;
    
    /**
     * @var Failures
     */
    protected $failures;
    
    
    /**
     * AbstractPutStrategy constructor.
     *
     * @param Connection $connection
     * @param Failures   $failures
     */
    private function __construct(Connection $connection, Failures $failures)
    {
        $this->connection = $connection;
        $this->failures   = $failures;
    }
    
    
    /**
     * Factory method for AbstractPutStrategy.
     *
     * @param Connection $connection
     *
     * @return AbstractPutStrategy
     */
    public static function create(Connection $connection): self
    {
        return new static($connection, Failures::create());
    }
    
    
    /**
     * @return string
     */
    public function failures(): string
    {
        return $this->failures->toString();
    }
}