<?php
/* --------------------------------------------------------------
 ChangedStrategy.php 2019-09-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Put;

use Gambio\Dragger\ApiTesting\SwaggerLike\Contracts\Verification\PutValidationStrategy;
use Gambio\Dragger\ApiTesting\SwaggerLike\Failure\SimpleFailure;
use Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Put\Expect;
use function array_keys;
use function implode;

/**
 * Class ChangedStrategy
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Put
 */
class ChangedStrategy extends AbstractPutStrategy implements PutValidationStrategy
{
    /**
     * @var array
     */
    private $data = [];
    
    
    /**
     * Validates the internal data.
     *
     * @param Expect[] $expectations
     *
     * @return bool
     */
    public function validate(Expect ...$expectations): bool
    {
        $actualData = [];
        foreach ($expectations as $expect) {
            $qb    = $this->connection->createQueryBuilder();
            $table = $expect->table();
            $query = $qb->select('*')->from($table);
            
            foreach ($expect->columns() as $identifier => $id) {
                $where = "{$this->connection->quoteIdentifier($identifier)} = {$qb->createNamedParameter($id)}";
                $query->where($where);
            }
            $actualData[$table] = $query->execute()->fetch();
        }
        
        if ($this->data === $actualData) {
            $tables  = implode('", "', array_keys($this->data));
            $message = <<<MSG
Failed asserting that data sets changed for tables "$tables".
MSG;
            $this->failures->add(SimpleFailure::create($message));
        }
        
        return !$this->failures->failed();
    }
    
    
    /**
     * Setup for validation (pre-request).
     * Should be used for example to count data sets before the request happen.
     *
     * @param Expect[] $expectations
     */
    public function setup(Expect ...$expectations): void
    {
        foreach ($expectations as $expect) {
            $qb    = $this->connection->createQueryBuilder();
            $table = $expect->table();
            
            $query = $qb->select('*')->from($table);
            
            foreach ($expect->columns() as $identifier => $id) {
                $where = "{$this->connection->quoteIdentifier($identifier)} = {$qb->createNamedParameter($id)}";
                $query->where($where);
            }
            $this->data[$table] = $query->execute()->fetch();
        }
    }
}