<?php
/* --------------------------------------------------------------
 PutTestValidator.php 2019-09-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Validator;

use Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Put\ChangedStrategy;
use Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Put\Expectations;

/**
 * Class PutTestValidator
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Validator
 */
class PutTestValidator
{
    /**
     * @var ChangedStrategy
     */
    private $changedStrategy;
    
    
    /**
     * PutTestValidator constructor.
     *
     * @param ChangedStrategy $changedStrategy
     */
    private function __construct(ChangedStrategy $changedStrategy)
    {
        $this->changedStrategy = $changedStrategy;
    }
    
    
    /**
     * Factory method for PutTestValidator.
     *
     * @param ChangedStrategy $changedStrategy
     *
     * @return PutTestValidator
     */
    public static function create(ChangedStrategy $changedStrategy) : self
    {
        return new static($changedStrategy);
    }
    
    
    /**
     * Performs the validation.
     *
     * @param Expectations $expectations
     *
     * @return bool
     */
    public function validate(Expectations $expectations) : bool
    {
        $failed = false;
        
        if (!$this->changedStrategy->validate(...$expectations->changed())) {
            $failed = true;
        }
        
        return !$failed;
    }
    
    
    /**
     * Setup of validation strategies.
     *
     * @param Expectations $expectations
     */
    public function setup(Expectations $expectations) : void
    {
        $this->changedStrategy->setup(...$expectations->changed());
    }
    
    
    /**
     * @return string
     */
    public function failures() : string
    {
        return $this->changedStrategy->failures();
    }
}