<?php
/* --------------------------------------------------------------
 RequiredValidator.php 2019-08-15
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Schema;

use Gambio\Dragger\ApiTesting\SwaggerLike\Failure\Failures;
use Gambio\Dragger\ApiTesting\SwaggerLike\Failure\PropertyFailure;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\HasRequired;
use function array_diff;
use function array_keys;
use function count;

/**
 * Class RequiredPropertiesValidator
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Schema
 */
class RequiredValidator
{
    /**
     * @var Failures
     */
    private $failures;
    
    
    /**
     * RequiredValidator constructor.
     *
     * @param Failures $failures
     */
    public function __construct(Failures $failures)
    {
        $this->failures = $failures;
    }
    
    
    /**
     * Validates response items.
     * Fails if not all required properties exists on $responseItem.
     *
     * @param HasRequired $required
     * @param array       $responseItem
     *
     * @return bool
     */
    public function validate(HasRequired $required, array $responseItem) : bool
    {
        $diff = array_diff($required->required(), array_keys($responseItem));
        
        if (count($diff) !== 0) {
            $this->failures->add(PropertyFailure::missingRequired($required, $responseItem));
            
            return false;
        }
        
        return true;
    }
}