<?php
/* --------------------------------------------------------------
 DeleteTestVerification.php 2019-08-28
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Delete;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Endpoint;
use Gambio\Dragger\ApiTesting\SwaggerLike\Traits\EndpointUrlResolver;

/**
 * Class DeleteTestVerification
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Delete
 */
class DeleteTestVerification
{
    use EndpointUrlResolver;
    
    /**
     * @var Endpoint
     */
    private $endpoint;
    
    /**
     * @var Expectations
     */
    private $expectations;
    
    /**
     * @var array|null
     */
    private $requestBody;
    
    /**
     * @var array
     */
    private $urlPlaceholders = [];
    
    
    /**
     * DeleteTestVerification constructor.
     *
     * @param Endpoint     $endpoint
     * @param Expectations $expectations
     */
    private function __construct(Endpoint $endpoint, Expectations $expectations)
    {
        $this->endpoint     = $endpoint;
        $this->expectations = $expectations;
    }
    
    
    /**
     * Factory method for DeleteTestVerification.
     *
     * @param Endpoint $endpoint
     *
     * @return DeleteTestVerification
     */
    public static function create(Endpoint $endpoint) : self
    {
        return new static($endpoint, Expectations::create());
    }
    
    
    /**
     * Adds a new delete verification.
     *
     * @param Expect[] $expectations
     */
    public function add(Expect ...$expectations) : void
    {
        foreach ($expectations as $verification) {
            $this->expectations->add($verification);
        }
    }
    
    
    /**
     * @return Endpoint
     */
    public function endpoint() : Endpoint
    {
        return $this->endpoint;
    }
    
    
    /**
     * @return Expectations
     */
    public function expectations() : Expectations
    {
        return $this->expectations;
    }
    
    
    /**
     * Sets custom request body for request to be tested.
     *
     * @param array $requestBody
     */
    public function withCustomRequestBody(array $requestBody) : void
    {
        $this->requestBody = $requestBody;
    }
    
    
    /**
     * Sets custom url parameters for request to be tested.
     *
     * @param array $urlPlaceholders
     */
    public function withUrlPlaceholders(array $urlPlaceholders) : void
    {
        $this->urlPlaceholders = $urlPlaceholders;
    }
    
    
    /**
     * @return string
     */
    public function requestMethod() : string
    {
        return $this->endpoint->method();
    }
    
    
    /**
     * @return string
     */
    public function requestPath() : string
    {
        return $this->resolveEndpointUrl($this->endpoint, $this->urlPlaceholders);
    }
    
    
    /**
     * @return array
     */
    public function requestOptions() : array
    {
        if ($this->requestBody) {
            return ['json' => $this->requestBody];
        }
        
        return [];
    }
}