<?php
/* --------------------------------------------------------------
 Expectations.php 2019-08-30
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Delete;

/**
 * Class Expectations
 * @package Gambio\Dragger\ApiTesting\SwaggerLike
 */
class Expectations
{
    /**
     * @var Expect[]
     */
    private $removed = [];
    
    /**
     * @var Expect[]
     */
    private $exists = [];
    
    
    /**
     * Expectations constructor.
     */
    private function __construct()
    {
    }
    
    
    /**
     * Factory method for expectations.
     *
     * @return Expectations
     */
    public static function create() : self
    {
        return new static();
    }
    
    
    /**
     * Adds new expectations.
     *
     * @param Expect[] $expectations
     */
    public function add(Expect ...$expectations) : void
    {
        foreach ($expectations as $expectation) {
            if ($expectation->is(Expect::TYPE_REMOVED)) {
                $this->removed[] = $expectation;
            }
            if ($expectation->is(Expect::TYPE_EXISTS)) {
                $this->exists[] = $expectation;
            }
        }
    }
    
    
    /**
     * @return Expect[]
     */
    public function removed() : array
    {
        return $this->removed;
    }
    
    
    /**
     * @return Expect[]
     */
    public function exists() : array
    {
        return $this->exists;
    }
}