<?php
/* --------------------------------------------------------------
 PostAffectedTables.php 2019-08-22
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Post;

use function array_keys;

/**
 * Class PostAffectedTables
 * @package Gambio\Dragger\ApiTesting\SwaggerLike\Verification\Post
 */
class PostAffectedTables
{
    /**
     * @var array
     */
    private $affected = [];
    
    
    /**
     * PostAffectedTables constructor.
     */
    private function __construct()
    {
    }
    
    
    /**
     * @return PostAffectedTables
     */
    public static function create() : self
    {
        return new static();
    }
    
    
    /**
     * @param string $table
     * @param int    $multiplier
     */
    public function add(string $table, int $multiplier) : void
    {
        $this->affected[$table] = $multiplier;
    }
    
    
    /**
     * Returns array of affected tables.
     * Format:
     * <pre>
     *  [
     *      $tableName => $tablesMultiplier,
     *  ]
     * </pre>
     * @return array
     */
    public function items() : array
    {
        return $this->affected;
    }
    
    
    /**
     * @return array
     */
    public function tablesOnly() : array
    {
        return array_keys($this->affected);
    }
}