<?php
/* --------------------------------------------------------------
 FixtureCreator.php 2020-04-30
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\DatabaseFixture;

use Doctrine\DBAL\Connection;
use Gambio\Dragger\DatabaseFixture\Processor\TableDataProcessor;
use Throwable;

/**
 * Class FixtureCreator
 * @package Gambio\Dragger\DatabaseFixture
 */
class FixtureCreator
{
    /**
     * @var Connection
     */
    private $connection;
    
    /**
     * @var TableDataProcessor
     */
    private $dataProcessor;
    
    
    /**
     * FixtureCreator constructor.
     *
     * @param Connection         $connection
     * @param TableDataProcessor $dataProcessor
     */
    public function __construct(Connection $connection, TableDataProcessor $dataProcessor)
    {
        $this->connection    = $connection;
        $this->dataProcessor = $dataProcessor;
    }
    
    
    /**
     * Creates an array fixture (as complete string) for the given tables.
     *
     * @param array $tables
     *
     * @return string
     */
    public function createFixture(array $tables): string
    {
        $data = [];
        foreach ($tables as $table) {
            $qb = $this->connection->createQueryBuilder();
            
            try {
                $result       = $qb->select('*')->from($table)->execute()->fetchAll();
                $data[$table] = $result;
            } catch (Throwable $e) {
            }
        }
        
        return $this->dataProcessor->createContent($data);
    }
}