<?php
/* --------------------------------------------------------------
 PackageFactory.php 2020-04-24
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\PackageComparator\Factories;

use Gambio\Dragger\PackageComparator\Model\Collections\Directories;
use Gambio\Dragger\PackageComparator\Model\Collections\Files;
use Gambio\Dragger\PackageComparator\Model\ComparePackage;
use Gambio\Dragger\PackageComparator\Model\Directory;
use Gambio\Dragger\PackageComparator\Model\File;

/**
 * Class PackageFactory
 * @package Gambio\Dragger\PackageComparator\Factories
 */
class PackageFactory
{
    /**
     * @param string    $name
     * @param Directory $root
     *
     * @return ComparePackage
     */
    public function createComparePackage(string $name, Directory $root): ComparePackage
    {
        return ComparePackage::create($name, $root);
    }
    
    
    /**
     * @param string $name
     * @param string $absolutePath
     * @param string $relativePath
     *
     * @return File
     */
    public function createFile(string $name, string $absolutePath, string $relativePath): File
    {
        return File::create($name, $absolutePath, $relativePath);
    }
    
    
    /**
     * @return Files
     */
    public function createFiles(): Files
    {
        return Files::create();
    }
    
    
    /**
     * @param string      $name
     * @param string      $absolutePath
     * @param string      $relativePath
     * @param Directories $directories
     * @param Files       $files
     *
     * @return Directory
     */
    public function createDirectory(
        string $name,
        string $absolutePath,
        string $relativePath,
        Directories $directories,
        Files $files
    ): Directory {
        return Directory::create($name, $absolutePath, $relativePath, $directories, $files);
    }
    
    
    /**
     * @return Directories
     */
    public function createDirectories(): Directories
    {
        return Directories::create();
    }
}