<?php
/* --------------------------------------------------------------
 Directory.php 2020-04-24
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\PackageComparator\Model;

use Gambio\Dragger\PackageComparator\Model\Collections\Directories;
use Gambio\Dragger\PackageComparator\Model\Collections\Files;

/**
 * Class Directory
 * @package Gambio\Dragger\PackageComparator\Model
 */
class Directory
{
    /**
     * @var string
     */
    private $name;
    
    /**
     * @var string
     */
    private $absolutePath;
    
    /**
     * @var string
     */
    private $relativePath;
    
    /**
     * @var Directories
     */
    private $directories;
    
    /**
     * @var Files
     */
    private $files;
    
    
    /**
     * Directory constructor.
     *
     * @param string      $name
     * @param string      $absolutePath
     * @param string      $relativePath
     * @param Directories $directories
     * @param Files       $files
     */
    private function __construct(
        string $name,
        string $absolutePath,
        string $relativePath,
        Directories $directories,
        Files $files
    ) {
        $this->name         = $name;
        $this->absolutePath = $absolutePath;
        $this->relativePath = $relativePath;
        $this->directories  = $directories;
        $this->files        = $files;
    }
    
    
    /**
     * Factory method for Directory.
     *
     * @param string      $name
     * @param string      $absolutePath
     * @param string      $relativePath
     * @param Directories $directories
     * @param Files       $files
     *
     * @return static
     */
    public static function create(
        string $name,
        string $absolutePath,
        string $relativePath,
        Directories $directories,
        Files $files
    ): self {
        return new static($name, $absolutePath, $relativePath, $directories, $files);
    }
    
    
    /**
     * @return string
     */
    public function name(): string
    {
        return $this->name;
    }
    
    
    /**
     * @return string
     */
    public function absolutePath(): string
    {
        return $this->absolutePath;
    }
    
    
    /**
     * @return string
     */
    public function relativePath(): string
    {
        return $this->relativePath;
    }
    
    
    /**
     * @return Directories
     */
    public function directories(): Directories
    {
        return $this->directories;
    }
    
    
    /**
     * @return Files
     */
    public function files(): Files
    {
        return $this->files;
    }
    
    
    /**
     * Searches for another directory with the same relative path.
     *
     * @param Directory $other
     *
     * @return $this|null
     */
    public function findDirectory(self $other): ?self
    {
        if ($this->relativePath === $other->relativePath) {
            return $this;
        }
        
        foreach ($this->directories as $directory) {
            if ($found = $directory->findDirectory($other)) {
                return $found;
            }
        }
        
        return null;
    }
}