<?php
/* --------------------------------------------------------------
 DiffVerifyProcessor.php 2020-04-30
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\PackageComparator\Processors;

use Gambio\Dragger\PackageComparator\Model\ComparePackage;
use Gambio\Dragger\PackageComparator\Utility\DirectoryReader;
use function array_values;
use function rtrim;
use function strpos;

/**
 * Class DiffVerifyProcessor
 * @package Gambio\Dragger\PackageComparator\Processors
 */
class DiffVerifyProcessor
{
    /**
     * @var DirectoryReader
     */
    private $directoryReader;
    
    
    /**
     * DiffVerifyProcessor constructor.
     *
     * @param DirectoryReader $directoryReader
     */
    public function __construct(DirectoryReader $directoryReader)
    {
        $this->directoryReader = $directoryReader;
    }
    
    
    /**
     * Verifies the $differences and removes any entries that are also present in the source package.
     *
     * @param ComparePackage $sourcePackage
     * @param array          $differences
     */
    public function process(ComparePackage $sourcePackage, array &$differences): void
    {
        $sourceFiles = $this->directoryReader->relativeFilePaths($sourcePackage->root());
        
        foreach ($differences as $index => $difference) {
            $difference = rtrim($difference, '/*');
            
            foreach ($sourceFiles as $sourceFile) {
                if (strpos($sourceFile, $difference) === 0) {
                    unset($differences[$index]);
                }
            }
        }
        $differences = array_values($differences);
    }
}