<?php
/* --------------------------------------------------------------
 FixtureServiceProvider.php 2019-08-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Application\Provider;

use Gambio\Dragger\Tools\Domain\DbFixture\DbFixtureRepository;
use Gambio\Dragger\Tools\Domain\DbFixture\Service as FixtureService;
use Gambio\Dragger\Tools\Infrastructure\Persistence\DbFixture\PdoMySqlReader;
use Gambio\Dragger\Tools\Infrastructure\Persistence\DbFixture\PdoMySqlRepository;
use Gambio\Dragger\Tools\Infrastructure\Persistence\DbFixture\PdoMySqlWriter;
use Gambio\Dragger\Tools\Infrastructure\Persistence\DbFixture\TableDataProcessor;
use League\Container\Container;
use League\Container\ServiceProvider\AbstractServiceProvider;
use PDO;

/**
 * Class FixtureServiceProvider
 * @package Gambio\Dragger\Tools\Application\Provider
 *
 * @property-read Container $container
 */
class FixtureServiceProvider extends AbstractServiceProvider
{
    /**
     * @var array
     */
    protected $provides = [
        FixtureService::class
    ];
    
    
    /**
     * Use the register method to register items with the container via the
     * protected $this->container property or the `getContainer` method
     * from the ContainerAwareTrait.
     *
     * @return void
     */
    public function register() : void
    {
        // PDO is required and there is an existing service provider
        $this->container->addServiceProvider(PdoServiceProvider::class);
        
        $this->container->add(FixtureService::class)->addArgument(DbFixtureRepository::class);
        $this->container->add(DbFixtureRepository::class, PdoMySqlRepository::class)->addArguments(
            [
                PdoMySqlReader::class,
                PdoMySqlWriter::class,
                TableDataProcessor::class,
            ]
        );
        
        $this->container->add(PdoMySqlReader::class)->addArgument(PDO::class);
        $this->container->add(PdoMySqlWriter::class)->addArgument(PDO::class);
        $this->container->add(TableDataProcessor::class);
    }
}