<?php
/* --------------------------------------------------------------
 PdoServiceProvider.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Application\Provider;

use Gambio\Dragger\Tools\Contracts\Configuration\DbCredentials;
use Gambio\Dragger\Tools\Core\DbCredentials as DatabaseCredentials;
use League\Container\Container;
use League\Container\ServiceProvider\AbstractServiceProvider;
use PDO;

/**
 * Class PdoServiceProvider
 * @package Gambio\Dragger\Tools\Application\Provider
 *
 * @property-read Container $container
 */
class PdoServiceProvider extends AbstractServiceProvider
{
    /**
     * @var array
     */
    protected $provides = [
        PDO::class,
        DbCredentials::class
    ];
    
    
    /**
     * Use the register method to register items with the container via the
     * protected $this->container property or the `getContainer` method
     * from the ContainerAwareTrait.
     *
     * @return void
     */
    public function register() : void
    {
        $host     = getenv('DB_HOST');
        $user     = getenv('DB_USER');
        $password = getenv('DB_PASSWORD');
        $name     = getenv('DB_NAME');
        
        $dsn = 'mysql:host=' . $host . ';dbname=' . $name . ';charset=utf8';
        
        $this->container->add(PDO::class)->addArguments(
            [
                $dsn,
                $user,
                $password
            ]
        )->addMethodCall('setAttribute', [PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION])->addMethodCall(
            'setAttribute', [
                              PDO::ATTR_DEFAULT_FETCH_MODE,
                              PDO::FETCH_ASSOC
                          ]
        );
        $this->container->add(DbCredentials::class, [DatabaseCredentials::class, 'create'])->addArguments(
            [
                $host,
                $user,
                $password,
                $name
            ]
        );
    }
}