<?php
/* --------------------------------------------------------------
 SqlRunnerServiceProvider.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Application\Provider;

use Gambio\Dragger\Tools\Domain\Commands\Sql\Service;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFileFactory;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlRepository;
use Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql\PdoSqlRepository;
use Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql\SqlFilePdoWriter;
use Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql\SqlFileReader;
use League\Container\Container;
use League\Container\ServiceProvider\AbstractServiceProvider;
use PDO;

/**
 * Class SqlRunnerServiceProvider
 * @package Gambio\Dragger\Tools\Application\Provider
 *
 * @property-read Container $container
 *
 * @Todo    : Rename this service provider and sql runner domain (including directories and so on)
 */
class SqlRunnerServiceProvider extends AbstractServiceProvider
{
    /**
     * @var array
     */
    protected $provides = [
        Service::class
    ];
    
    
    /**
     * Use the register method to register items with the container via the
     * protected $this->container property or the `getContainer` method
     * from the ContainerAwareTrait.
     *
     * @return void
     */
    public function register() : void
    {
        $this->container->add(Service::class)->addArgument(SqlRepository::class);
        $this->container->add(SqlRepository::class, PdoSqlRepository::class)->addArguments(
            [
                SqlFileReader::class,
                SqlFilePdoWriter::class
            ]
        );
        $this->container->add(SqlFileReader::class)->addArgument(SqlFileFactory::class);
        $this->container->add(SqlFilePdoWriter::class)->addArgument(PDO::class);
        $this->container->add(SqlFileFactory::class);
    }
}