<?php
/* --------------------------------------------------------------
 DbCredentials.php 2019-07-16
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Core;

/**
 * Class DbCredentials
 *
 * @package Gambio\Dragger\Tools\Core
 */
class DbCredentials implements \Gambio\Dragger\Tools\Contracts\Configuration\DbCredentials
{
    /**
     * @var string
     */
    private $dbHost;
    
    /**
     * @var string
     */
    private $dbUser;
    
    /**
     * @var string
     */
    private $dbPassword;
    
    /**
     * @var string
     */
    private $dbName;
    
    
    /**
     * DbCredentials constructor.
     *
     * @param string $dbHost
     * @param string $dbUser
     * @param string $dbPassword
     * @param string $dbName
     */
    private function __construct(string $dbHost, string $dbUser, string $dbPassword, string $dbName)
    {
        $this->dbHost     = $dbHost;
        $this->dbUser     = $dbUser;
        $this->dbPassword = $dbPassword;
        $this->dbName     = $dbName;
    }
    
    
    /**
     * Factory method for DbCredentials.
     *
     * @param string $dbHost
     * @param string $dbUser
     * @param string $dbPassword
     * @param string $dbName
     *
     * @return DbCredentials
     */
    public static function create(string $dbHost, string $dbUser, string $dbPassword, string $dbName) : self
    {
        return new static($dbHost, $dbUser, $dbPassword, $dbName);
    }
    
    
    /**
     * @return string
     */
    public function dbHost() : string
    {
        return $this->dbHost;
    }
    
    
    /**
     * @return string
     */
    public function dbUser() : string
    {
        return $this->dbUser;
    }
    
    
    /**
     * @return string
     */
    public function dbPassword() : string
    {
        return $this->dbPassword;
    }
    
    
    /**
     * @return string
     */
    public function dbName() : string
    {
        return $this->dbName;
    }
}