<?php
/* --------------------------------------------------------------
 ConfigurationsQuery.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Domain\GxInstaller\Steps\CreateAccount;

/**
 * Class ConfigurationsQuery
 * @package Gambio\Dragger\Tools\Domain\GxInstaller\Steps\CreateAccount
 */
class ConfigurationsQuery
{
    /**
     * Gambio installer query.
     *
     * @return string
     */
    public static function emailQuery() : string
    {
        return <<<QUERY
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'CONTACT_US_REPLY_ADDRESS';
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'EMAIL_SUPPORT_REPLY_ADDRESS';
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'EMAIL_BILLING_REPLY_ADDRESS';
QUERY;
    }
    
    
    /**
     * Creates params for prepared statement.
     *
     * @param CreateAccountData $data
     *
     * @return array
     */
    public static function emailParams(CreateAccountData $data) : array
    {
        return [
            'email' => $data->email()
        ];
    }
    
    
    /**
     * Gambio installer query.
     *
     * @return string
     */
    public static function companyQuery() : string
    {
        return <<<QUERY
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'CONTACT_US_NAME';
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'CONTACT_US_REPLY_ADDRESS_NAME';
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'EMAIL_SUPPORT_NAME';
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'EMAIL_SUPPORT_REPLY_ADDRESS_NAME';
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'EMAIL_BILLING_NAME';
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'EMAIL_BILLING_REPLY_ADDRESS_NAME';
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'STORE_OWNER';
UPDATE `configuration` SET `configuration_value`= :company WHERE `configuration_key` = 'COMPANY_NAME';
QUERY;
    }
    
    
    /**
     * Creates params for prepared statement.
     *
     * @param CreateAccountData $data
     *
     * @return array
     */
    public static function companyParams(CreateAccountData $data) : array
    {
        return [
            'company' => $data->company()
        ];
    }
    
    
    /**
     * Gambio installer query.
     *
     * @return string
     */
    public static function customerQuery() : string
    {
        return <<<QUERY
UPDATE `configuration` SET `configuration_value`= :firstName WHERE `configuration_key` = 'TRADER_FIRSTNAME';
UPDATE `configuration` SET `configuration_value`= :lastName WHERE `configuration_key` = 'TRADER_NAME';
UPDATE `configuration` SET `configuration_value`= :streetAddress WHERE `configuration_key` = 'TRADER_STREET';
UPDATE `configuration` SET `configuration_value`= :streetNumber WHERE `configuration_key` = 'TRADER_STREET_NUMBER';
UPDATE `configuration` SET `configuration_value`= :postcode WHERE `configuration_key` = 'TRADER_ZIPCODE';
UPDATE `configuration` SET `configuration_value`= :city WHERE `configuration_key` = 'TRADER_LOCATION';
UPDATE `configuration` SET `configuration_value`= :phone WHERE `configuration_key` = 'TRADER_TEL';
QUERY;
    }
    
    
    /**
     * Creates params for prepared statement.
     *
     * @param CreateAccountData $data
     *
     * @return array
     */
    public static function customerParams(CreateAccountData $data) : array
    {
        return [
            'firstName'     => $data->firstName(),
            'lastName'      => $data->lastName(),
            'streetAddress' => $data->streetAddress(),
            'streetNumber'  => $data->houseNumber(),
            'postcode'      => $data->postCode(),
            'city'          => $data->city(),
            'phone'         => $data->phone(),
        ];
    }
    
    
    /**
     * Gambio installer query.
     *
     * @return string
     */
    public static function countryQuery() : string
    {
        return <<<QUERY
UPDATE `configuration` SET `configuration_value`= '81' WHERE `configuration_key` = 'STORE_COUNTRY';
UPDATE `configuration` SET `configuration_value`= '1355' WHERE `configuration_key` = 'STORE_ZONE';
QUERY;
    }
    
    
    /**
     * Gambio installer query.
     *
     * @return string
     */
    public static function finalizeQuery() : string
    {
        return <<<QUERY
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'STORE_OWNER_EMAIL_ADDRESS';
UPDATE `configuration` SET `configuration_value`= :storeName WHERE `configuration_key` = 'STORE_NAME';
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'EMAIL_FROM';
UPDATE `configuration` SET `configuration_value`= '81' WHERE `configuration_key` = 'SHIPPING_ORIGIN_COUNTRY';
UPDATE `configuration` SET `configuration_value`= :postCode WHERE `configuration_key` = 'SHIPPING_ORIGIN_ZIP';
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'EMAIL_BILLING_ADDRESS';
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'CONTACT_US_EMAIL_ADDRESS';
UPDATE `configuration` SET `configuration_value`= :email WHERE `configuration_key` = 'EMAIL_SUPPORT_ADDRESS';
INSERT INTO
    `gm_configuration`
(`gm_key`,`gm_value`)
    VALUES
('MODULE_CENTER_ERRORREPORTING_INSTALLED', '0');
INSERT INTO
    `gm_configuration`
(`gm_key`, `gm_value`)
    VALUES
('ADMIN_FEED_ACCEPTED_SHOP_INFORMATION_DATA_PROCESSING', 'false');
QUERY;
    }
    
    
    /**
     * Creates params for prepared statement.
     *
     * @param CreateAccountData $data
     *
     * @return array
     */
    public static function finalizeParams(CreateAccountData $data) : array
    {
        return [
            'email'     => $data->email(),
            'storeName' => $data->storeName(),
            'postCode'  => $data->postCode(),
        ];
    }
}