<?php
/* --------------------------------------------------------------
 CreateAccountData.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Domain\GxInstaller\Steps\CreateAccount;

use Webmozart\Assert\Assert;

/**
 * Class CreateAccountData
 * @package Gambio\Dragger\Tools\Domain\GxInstaller\Steps\CreateAccount
 */
class CreateAccountData
{
    /**
     * @var string
     */
    private $firstName;
    
    /**
     * @var string
     */
    private $lastName;
    
    /**
     * @var string
     */
    private $gender;
    
    /**
     * @var string
     */
    private $email;
    
    /**
     * @var string
     */
    private $phone;
    
    /**
     * @var string
     */
    private $pw;
    
    /**
     * @var string
     */
    private $company;
    
    /**
     * @var string
     */
    private $streetAddress;
    
    /**
     * @var string
     */
    private $houseNumber;
    
    /**
     * @var string
     */
    private $postCode;
    
    /**
     * @var string
     */
    private $city;
    
    /**
     * @var string
     */
    private $state;
    
    /**
     * @var string
     */
    private $storeName;
    
    
    /**
     * CreateAccountData constructor.
     *
     * @param string $firstName
     * @param string $lastName
     * @param string $gender
     * @param string $email
     * @param string $phone
     * @param string $pw
     * @param string $company
     * @param string $streetAddress
     * @param string $houseNumber
     * @param string $postCode
     * @param string $city
     * @param string $state
     * @param string $storeName
     */
    private function __construct(
        string $firstName,
        string $lastName,
        string $gender,
        string $email,
        string $phone,
        string $pw,
        string $company,
        string $streetAddress,
        string $houseNumber,
        string $postCode,
        string $city,
        string $state,
        string $storeName
    ) {
        $this->firstName     = $firstName;
        $this->lastName      = $lastName;
        $this->gender        = $gender;
        $this->email         = $email;
        $this->phone         = $phone;
        $this->pw            = $pw;
        $this->company       = $company;
        $this->streetAddress = $streetAddress;
        $this->houseNumber   = $houseNumber;
        $this->postCode      = $postCode;
        $this->city          = $city;
        $this->state         = $state;
        $this->storeName     = $storeName;
    }
    
    
    /**
     * Factory method for create account data.
     *
     * @param array $data
     *
     * @return CreateAccountData
     */
    public static function fromArray(array $data) : self
    {
        $firstName     = static::input($data, 'firstName');
        $lastName      = static::input($data, 'lastName');
        $gender        = static::input($data, 'gender');
        $email         = static::input($data, 'email');
        $phone         = static::input($data, 'phone');
        $pw            = static::input($data, 'pw');
        $company       = static::input($data, 'company');
        $streetAddress = static::input($data, 'streetAddress');
        $houseNumber   = static::input($data, 'houseNumber');
        $postCode      = static::input($data, 'postCode');
        $city          = static::input($data, 'city');
        $state         = static::input($data, 'state');
        $storeName     = static::input($data, 'storeName');
        
        return new static(
            $firstName, $lastName, $gender, $email, $phone, $pw, $company, $streetAddress, $houseNumber, $postCode,
            $city, $state, $storeName
        );
    }
    
    
    private static function input(array $data, string $key) : string
    {
        Assert::keyExists($data, $key);
        $value = $data[$key];
        Assert::stringNotEmpty($key);
        
        return $value;
    }
    
    
    /**
     * @return string
     */
    public function firstName() : string
    {
        return $this->firstName;
    }
    
    
    /**
     * @return string
     */
    public function lastName() : string
    {
        return $this->lastName;
    }
    
    
    /**
     * @return string
     */
    public function gender() : string
    {
        return $this->gender;
    }
    
    
    /**
     * @return string
     */
    public function email() : string
    {
        return $this->email;
    }
    
    
    /**
     * @return string
     */
    public function phone() : string
    {
        return $this->phone;
    }
    
    
    /**
     * @return string
     */
    public function pw() : string
    {
        return $this->pw;
    }
    
    
    /**
     * @return string
     */
    public function company() : string
    {
        return $this->company;
    }
    
    
    /**
     * @return string
     */
    public function streetAddress() : string
    {
        return $this->streetAddress;
    }
    
    
    /**
     * @return string
     */
    public function houseNumber() : string
    {
        return $this->houseNumber;
    }
    
    
    /**
     * @return string
     */
    public function postCode() : string
    {
        return $this->postCode;
    }
    
    
    /**
     * @return string
     */
    public function city() : string
    {
        return $this->city;
    }
    
    
    /**
     * @return string
     */
    public function state() : string
    {
        return $this->state;
    }
    
    
    /**
     * @return string
     */
    public function storeName() : string
    {
        return $this->storeName;
    }
}