<?php
/* --------------------------------------------------------------
 InstallDb.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Domain\GxInstaller\Steps;

use Gambio\Dragger\Tools\Domain\Commands\Sql\Service;
use Gambio\Dragger\Tools\Domain\Exception\GxInstaller\InstallationFailedException;

/**
 * Class InstallDb
 * @package Gambio\Dragger\Tools\Domain\GxInstaller\Steps
 */
class InstallDb
{
    /**
     * @var Service
     */
    private $sqlService;
    
    
    /**
     * InstallDb constructor.
     *
     * @param Service $sqlService
     */
    public function __construct(Service $sqlService)
    {
        $this->sqlService = $sqlService;
        $this->sqlService->abortOnError(true);
    }
    
    
    /**
     * Executes the step task.
     *
     * @param string $sqlDir
     *
     * @throws InstallationFailedException
     */
    public function run(string $sqlDir) : void
    {
        $result = $this->sqlService->importFromDir($sqlDir);
        if (!$result[Service::SUCCESS_KEY]) {
            $failedFiles = implode(
                PHP_EOL, array_map(
                           static function ($element) {
                               return $element[Service::FILES_KEY];
                           }, $result[Service::ERRORS_KEY]
                       )
            );
            
            $msg = 'Failed to install shop database!' . PHP_EOL;
            $msg .= 'Invalid files: ' . PHP_EOL . $failedFiles . PHP_EOL;
            
            throw new InstallationFailedException($msg);
        }
    }
}