<?php
/* --------------------------------------------------------------
 SetupShop.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Domain\GxInstaller\Steps;

use Gambio\Dragger\Tools\Domain\Exception\GxInstaller\InstallationFailedException;
use Gambio\Dragger\Tools\Domain\GxInstaller\Steps\SetupShop\Queries;
use PDO;
use PDOException;

/**
 * Class SetupShop
 * @package Gambio\Dragger\Tools\Domain\GxInstaller\Steps
 */
class SetupShop
{
    /**
     * @var PDO
     */
    private $pdo;
    
    
    /**
     * SetupShop constructor.
     *
     * @param PDO $pdo
     */
    public function __construct(PDO $pdo)
    {
        $this->pdo = $pdo;
    }
    
    
    /**
     * Executes all steps tasks.
     *
     * @throws InstallationFailedException
     */
    public function run() : void
    {
        try {
            $this->pdo->beginTransaction();
            
            $this->execute(Queries::gmContents());
            $this->execute(Queries::customersStatus());
            $this->execute(Queries::personalOffers());
            $this->execute(Queries::fulltext());
            $this->execute(Queries::finalize());
            
            $this->pdo->commit();
        } catch (PDOException $e) {
            $this->pdo->rollBack();
            
            throw new InstallationFailedException('SetupShop failed', 0, $e);
        }
    }
    
    
    /**
     * Executes the query.
     *
     * @param string $query
     *
     * @throws PDOException
     */
    private function execute(string $query) : void
    {
        $result = $this->pdo->exec($query);
        
        if ($result === false) {
            $this->fail($query);
        }
    }
    
    
    /**
     * Triggers failure on invalid sql query.
     *
     * @param string $query
     *
     * @throws PDOException
     */
    private function fail(string $query) : void
    {
        $error = 'Could not execute query: ' . $query;
        throw new PDOException($error);
    }
}