<?php
/* --------------------------------------------------------------
 Dragger.php 2019-06-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools;

use Exception;
use Gambio\Dragger\Tools\Contracts\Configuration\DbCredentials;
use Gambio\Dragger\Tools\Domain\Commands\GxTestConfiguration\GxTestConfiguration;
use Gambio\Dragger\Tools\Domain\Commands\GxTestConfiguration\Service as InstallerService;
use Gambio\Dragger\Tools\Domain\Commands\Sql\Service;

/**
 * Class Dragger
 * @package Gambio\Dragger\Tools
 */
class Dragger
{
    /**
     * Creates a tests.config.inc.php file for the gx shop testing.
     *
     * @param GxTestConfiguration $configuration
     * @param string              $destination
     *
     * @return array
     */
    public static function createGxTestsConfig(GxTestConfiguration $configuration, string $destination) : array
    {
        try {
            $service = new InstallerService();
            $service->createTestsConfig($configuration, $destination);
            
            return ['success' => true];
        } catch (Exception $e) {
            return ['success' => false, 'message' => $e->getMessage()];
        }
    }
    
    
    /**
     * Imports all sql files in the given path (no recursion).
     *
     * @param string        $sqlDirectory
     * @param DbCredentials $credentials
     *
     * @return array
     */
    public static function runSql(string $sqlDirectory, DbCredentials $credentials) : array
    {
        $service = Service::fromDbCredentials($credentials);
        
        return $service->importFromDir($sqlDirectory);
    }
}