<?php
/* --------------------------------------------------------------
 FixtureFacade.php 2019-10-21
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools;

use Gambio\Dragger\Tools\Application\Provider\FixtureServiceProvider;
use Gambio\Dragger\Tools\Domain\DbFixture\Fixture;
use Gambio\Dragger\Tools\Domain\DbFixture\Service;
use InvalidArgumentException;
use League\Container\Container;

/**
 * Class FixtureFacade
 * @package Gambio\Dragger\Tools
 */
class FixtureFacade
{
    /**
     * Imports a database fixture.
     *
     * @param $fixture
     */
    public static function import($fixture): void
    {
        if (!$fixture instanceof Fixture) {
            if (!is_string($fixture)) {
                $msg = 'Provided $fixture must be either a string or an instance of ' . Fixture::class . ".\n";
                throw new InvalidArgumentException($msg);
            }
            $fixture = Fixture::fromFile($fixture);
        }
        
        /** @var Service $service */
        $app     = static::loadApp();
        $service = $app->get(Service::class);
        $service->importFixture($fixture);
    }
    
    
    /**
     * Loads all components for the database fixture micro service.
     *
     * @return Container
     */
    private static function loadApp(): Container
    {
        $container = new Container();
        $container->addServiceProvider(FixtureServiceProvider::class);
        
        return $container;
    }
}