<?php
/* --------------------------------------------------------------
 PdoSqlRepository.php 2019-06-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql;

use Gambio\Dragger\Tools\Domain\Commands\Sql\Path;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFile;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFileCollection;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlRepository;

/**
 * Class PdoSqlRepository
 * @package Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql
 */
class PdoSqlRepository implements SqlRepository
{
    /**
     * @var SqlFileReader
     */
    private $reader;
    
    /**
     * @var SqlFilePdoWriter
     */
    private $writer;
    
    
    /**
     * PdoSqlRepository constructor.
     *
     * @param SqlFileReader    $reader
     * @param SqlFilePdoWriter $writer
     */
    public function __construct(SqlFileReader $reader, SqlFilePdoWriter $writer)
    {
        $this->reader = $reader;
        $this->writer = $writer;
    }
    
    
    /**
     * Scans the given path for sql files and returns a collection of them.
     *
     * @param Path $path
     *
     * @return SqlFileCollection
     */
    public function scan(Path $path) : SqlFileCollection
    {
        return $this->reader->scan($path);
    }
    
    
    /**
     * Imports an sql file.
     *
     * @param SqlFile $sqlFile
     */
    public function import(SqlFile $sqlFile) : void
    {
        $this->writer->run($sqlFile);
    }
}