<?php
/* --------------------------------------------------------------
 SqlFilePdoWriter.php 2019-06-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql;

use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFile;
use PDO;

/**
 * Class SqlFilePdoWriter
 * @package Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql
 */
class SqlFilePdoWriter
{
    /**
     * @var PDO
     */
    private $pdo;
    
    
    /**
     * SqlFilePdoWriter constructor.
     *
     * @param PDO $pdo
     */
    public function __construct(PDO $pdo)
    {
        $this->pdo = $pdo;
    }
    
    
    /**
     * Executes the sql file.
     *
     * @param SqlFile $file
     */
    public function run(SqlFile $file) : void
    {
        $query = file_get_contents($file->toString());
        
        $statement = $this->pdo->prepare($query);
        $tries     = 0;
        
        $statement->execute();
        // installer sql files contain multiple statements
        // to ensure no error occurred, all result checks have to be checked
        while ($statement->nextRowset() && $tries < 10) {
            $tries++;
        }
    }
}