<?php
/* --------------------------------------------------------------
 SqlFilePdoWriterTest.php 2019-06-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql;

use Dotenv\Dotenv;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFile;
use Gambio\Dragger\Tools\Domain\Exception\Commands\Sql\InvalidSqlException;
use PDO;
use PDOException;
use PHPUnit\Framework\TestCase;

class SqlFilePdoWriterTest extends TestCase
{
    /**
     * @var PDO
     */
    private static $pdo;
    
    /**
     * @var SqlFilePdoWriter
     */
    private $writer;
    
    
    public static function setUpBeforeClass()
    {
        static::$pdo = static::getPdo();
    }
    
    
    protected function setUp()
    {
        $this->writer = new SqlFilePdoWriter(static::$pdo);
        static::$pdo->exec('DROP TABLE IF EXISTS `roles`;');
    }
    
    
    public function testExecutesSqlFile() : void
    {
        $sqlFile = SqlFile::fromPath(__DIR__ . '/fixtures/roles.sql');
        $this->writer->run($sqlFile);
        
        $this->assertTableExists('roles');
    }
    
    
    public function testThrowsExceptionIfPdoErrorOccurs() : void
    {
        $this->expectException(PDOException::class);
        $sqlFile = SqlFile::fromPath(__DIR__ . '/fixtures/users.sql');
        $this->writer->run($sqlFile);
    }
    
    
    private function assertTableExists(string $table) : void
    {
        $this->assertTrue($this->tableExists($table), "Table '{$table}' not exists.");
    }
    
    
    private function tableExists(string $table) : bool
    {
        $query = "SHOW TABLES LIKE '{$table}';";
        
        return static::$pdo->query($query)->fetch() !== false;
    }
    
    
    protected static function getPdo() : PDO
    {
        Dotenv::create(__DIR__ . '/../../../../../../..')->load();
        
        $host     = getenv('DB_HOST');
        $user     = getenv('DB_USER');
        $password = getenv('DB_PASSWORD');
        $name     = getenv('DB_NAME');
        
        $dsn = "mysql:host={$host};dbname={$name};charset=utf8";
        
        $pdo = new PDO($dsn, $user, $password);
        $pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        return $pdo;
    }
}