<?php
/* --------------------------------------------------------------
 SqlFileReaderTest.php 2019-06-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Infrastructure\Persistence\Commands\Sql;

use Gambio\Dragger\Tools\Domain\Commands\Sql\Path;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFile;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFileCollection;
use Gambio\Dragger\Tools\Domain\Commands\Sql\SqlFileFactory;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class SqlFileReaderTest extends TestCase
{
    /**
     * @var SqlFileReader
     */
    private $reader;
    
    /**
     * @var MockObject|SqlFileFactory
     */
    private $factory;
    
    /**
     * @var MockObject|SqlFileCollection
     */
    private $collection;
    
    /**
     * @var MockObject|SqlFile
     */
    private $firstFile;
    
    /**
     * @var MockObject|SqlFile
     */
    private $secondFile;
    
    /**
     * @var MockObject|SqlFile
     */
    private $thirdFile;
    
    
    protected function setUp()
    {
        $this->collection = $this->createMock(SqlFileCollection::class);
        $this->firstFile  = $this->createMock(SqlFile::class);
        $this->secondFile = $this->createMock(SqlFile::class);
        $this->thirdFile  = $this->createMock(SqlFile::class);
        
        $this->factory = $this->createMock(SqlFileFactory::class);
        $this->factory->method('createSqlFileCollection')->willReturn($this->collection);
        $this->factory->method('createSqlFile')->will(
            $this->onConsecutiveCalls($this->firstFile, $this->secondFile, $this->thirdFile)
        );
        
        $this->reader = new SqlFileReader($this->factory);
    }
    
    
    public function testScansAListOfSqlFiles() : void
    {
        $createFileArgs = [
            [$this->equalTo(__DIR__ . '/fixtures/role_user.sql')],
            [$this->equalTo(__DIR__ . '/fixtures/roles.sql')],
            [$this->equalTo(__DIR__ . '/fixtures/users.sql')],
        ];
        
        $this->factory->expects($this->once())->method('createSqlFileCollection');
        $this->factory->expects($this->exactly(3))->method('createSqlFile')->withConsecutive(...$createFileArgs);
        
        $path = $this->createConfiguredMock(
            Path::class, [
                           'toString' => __DIR__ . '/fixtures'
                       ]
        );
        $this->reader->scan($path);
    }
    
    
    public function testAddsScannedFilesToCollection() : void
    {
        $collectionArgs = [
            [$this->identicalTo($this->firstFile)],
            [$this->identicalTo($this->secondFile)],
            [$this->identicalTo($this->thirdFile)],
        ];
        $this->collection->expects($this->exactly(3))->method('add')->withConsecutive(...$collectionArgs);
        
        $path = $this->createConfiguredMock(
            Path::class, [
                           'toString' => __DIR__ . '/fixtures'
                       ]
        );
        $this->reader->scan($path);
    }
}