<?php
/* --------------------------------------------------------------
 PdoMySqlReaderTest.php 2019-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Infrastructure\Persistence\DbFixture;

use Dotenv\Dotenv;
use PDO;
use PHPUnit\Framework\TestCase;

class PdoMySqlReaderTest extends TestCase
{
    public const SAMPLE_TABLES = [
        'foo',
        'bar'
    ];
    
    public const EXPECTED_DATA = [
        'foo' => [
            [
                'id'      => '1',
                'foo_col' => 'First_foo'
            ],
            [
                'id'      => '2',
                'foo_col' => 'Second_foo'
            ]
        ],
        'bar' => [
            [
                'id'      => '1',
                'bar_col' => 'First_bar'
            ],
            [
                'id'      => '2',
                'bar_col' => 'Second_bar'
            ]
        ]
    ];
    
    /**
     * @var PDO
     */
    private static $pdo;
    
    /**
     * @var PdoMysqlReader
     */
    private $reader;
    
    
    protected function setUp()
    {
        $this->reader = new PdoMySqlReader(static::$pdo);
    }
    
    
    public function testFetchesTableData() : void
    {
        $this->assertEquals(self::EXPECTED_DATA, $this->reader->fetchData(self::SAMPLE_TABLES));
    }
    
    
    public static function setUpBeforeClass()
    {
        static::initPdo();
        static::createTestTables();
        static::seedTables();
    }
    
    
    public static function tearDownAfterClass()
    {
        foreach (self::SAMPLE_TABLES as $table) {
            $query = "DROP TABLE `{$table}`;";
            static::$pdo->exec($query);
        }
    }
    
    
    private static function initPdo() : void
    {
        if (null === static::$pdo) {
            Dotenv::create(__DIR__ . '/../../../../../..')->load();
            
            $host     = getenv('DB_HOST');
            $user     = getenv('DB_USER');
            $password = getenv('DB_PASSWORD');
            $name     = getenv('DB_NAME');
            
            $dsn = 'mysql:host=' . $host . ';dbname=' . $name . ';charset=utf8';
            
            static::$pdo = new PDO($dsn, $user, $password);
            static::$pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
            static::$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        }
    }
    
    
    private static function createTestTables() : void
    {
        $query = <<<'QUERY'
CREATE TABLE IF NOT EXISTS %s (
`id` INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
`%s_col` VARCHAR(255) NOT NULL
) ENGINE InnoDb CHARSET `utf8`;
QUERY;
        
        foreach (self::SAMPLE_TABLES as $table) {
            static::$pdo->exec(sprintf($query, $table, $table));
        }
    }
    
    
    private static function seedTables() : void
    {
        foreach (self::SAMPLE_TABLES as $table) {
            $query = "INSERT INTO `{$table}` (`{$table}_col`) VALUES ('First_{$table}'), ('Second_{$table}')";
            static::$pdo->exec($query);
        }
    }
}