<?php
/* --------------------------------------------------------------
 ServiceTest.php 2019-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Tools\Domain\DbFixture;

use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class ServiceTest extends TestCase
{
    /**
     * @var Service
     */
    private $service;
    
    /**
     * @var MockObject|DbFixtureRepository
     */
    private $repository;
    
    
    protected function setUp()
    {
        $this->repository = $this->createMock(DbFixtureRepository::class);
        
        $this->service = new Service($this->repository);
    }
    
    
    public function testMessagesRepositoryToCreateDatabaseFixture() : void
    {
        $tables      = $this->createMock(Tables::class);
        $destination = $this->createMock(Destination::class);
        $fixture     = $this->createMock(NewFixture::class);
        
        $this->repository->expects($this->once())->method('create')->with($this->identicalTo($tables))->willReturn(
            $fixture
        );
        $this->repository->expects($this->once())->method('save')->with(
            $this->identicalTo($fixture), $this->identicalTo($destination)
        );
        
        $this->service->createFixture($tables, $destination);
    }
    
    
    public function testMessagesRepositoryToImportDatabaseFixture() : void
    {
        $fixture = $this->createMock(Fixture::class);
        
        $this->repository->expects($this->once())->method('import')->with($this->equalTo($fixture));
        
        $this->service->importFixture($fixture);
    }
}