<?php
/* --------------------------------------------------------------
 IdentifierChangerTest.php 2019-08-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Faker;

use InvalidArgumentException;
use PHPUnit\Framework\TestCase;
use function random_int;

class IdentifierChangerTest extends TestCase
{
    /**
     * @var IdentifierChanger
     */
    private $changer;
    
    
    protected function setUp()
    {
        $this->changer = new IdentifierChanger();
    }
    
    
    public function testChangesEntityDataSetsId() : void
    {
        $data     = [
            'id'  => random_int(500, 999),
            'foo' => 'bar'
        ];
        $newId    = 4;
        $expected = [
            'id'  => $newId,
            'foo' => 'bar'
        ];
        
        $this->assertEquals($expected, $this->changer->changeEntity($data, 'id', $newId));
    }
    
    
    public function testCanNotChangeEntitiesIfIdentifierNotExists() : void
    {
        $this->expectException(InvalidArgumentException::class);
        $data = ['foo' => 'bar'];
        $this->changer->changeEntity($data, 'id', 1);
    }
    
    
    public function testRejectsListIfEntityShouldBeChanged() : void
    {
        $this->expectException(InvalidArgumentException::class);
        $data = [['id' => 2]];
        $this->changer->changeEntity($data, 'id', 1);
    }
    
    
    public function testChangesEntityListDataSetIds() : void
    {
        $data     = [
            [
                'id'  => random_int(500, 999),
                'foo' => 'bar'
            ],
            [
                'id'  => random_int(500, 999),
                'foo' => 'baz'
            ]
        ];
        $expected = [
            [
                'id'  => 5,
                'foo' => 'bar'
            ],
            [
                'id'  => 10,
                'foo' => 'baz'
            ]
        ];
        
        $this->assertEquals($expected, $this->changer->changeList($data, 'id', [5, 10]));
    }
    
    
    public function testCanNotChangeListIfAmountOfNewIdsIsShorterThanListLength() : void
    {
        $this->expectException(InvalidArgumentException::class);
        $data = [
            [
                'id'  => random_int(500, 999),
                'foo' => 'bar'
            ],
            [
                'id'  => random_int(500, 999),
                'foo' => 'baz'
            ]
        ];
        $this->changer->changeList($data, 'id', [2]);
    }
    
    
    public function testCanNotChangeListIfAmountOfNewIdsIsLongerThanListLength() : void
    {
        $this->expectException(InvalidArgumentException::class);
        $data = [
            [
                'id'  => random_int(500, 999),
                'foo' => 'bar'
            ],
            [
                'id'  => random_int(500, 999),
                'foo' => 'baz'
            ]
        ];
        $this->changer->changeList($data, 'id', [2, 4, 6]);
    }
    
    
    public function testCanNotChangeListIfIdentifierNotExists() : void
    {
        $this->expectException(InvalidArgumentException::class);
        $data = [
            [
                'id'  => random_int(500, 999),
                'foo' => 'bar'
            ],
            [
                'id'  => random_int(500, 999),
                'foo' => 'baz'
            ]
        ];
        
        $this->changer->changeList($data, 'ids', [5, 10]);
    }
}
