<?php
/* --------------------------------------------------------------
 SchemaDataFakerTest.php 2019-08-12
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Faker;

use Faker\Factory;
use Gambio\Dragger\ApiTesting\SwaggerLike\AssertApi;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection\Properties;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property\ListProperty;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property\ObjectListProperty;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property\ObjectProperty;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Property\ScalarProperty;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Schema\Schema;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Schema\SchemaList;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Schema\SchemaListScalar;
use PHPUnit\Framework\TestCase;

class SchemaDataFakerTest extends TestCase
{
    /**
     * @var SchemaDataFaker
     */
    private $schemaFaker;
    
    
    protected function setUp()
    {
        $this->schemaFaker = new SchemaDataFaker(Factory::create('de_DE'));
    }
    
    
    public function testCreatesDataArrayFromSchemaModel() : void
    {
        $properties = Properties::create();
        $properties->add(ScalarProperty::create('scalar-property', 'integer'));
        $properties->add(ListProperty::create('list-property', 'string'));
        
        $objectProperties = Properties::create();
        $objectProperties->add(ScalarProperty::create('object-scalar-property', 'boolean'));
        $objectProperties->add(ListProperty::create('object-scalar-list-property', 'double'));
        $properties->add(
            ObjectProperty::create(
                'object-property', $objectProperties, ['object-scalar-property', 'object-scalar-list-property']
            )
        );
        
        $objectListProperties = Properties::create();
        $objectListProperties->add(ScalarProperty::create('object-list-scalar-property', 'string'));
        $objectListProperties->add(ListProperty::create('object-list-list-property', 'integer'));
        $properties->add(
            ObjectListProperty::create(
                'object-list-property', $objectListProperties,
                ['object-list-scalar-property', 'object-list-list-property']
            )
        );
        
        $schema = Schema::create(
            'LightweightProduct', $properties,
            ['scalar-property', 'list-property', 'object-property', 'object-list-property']
        );
        
        $data = $this->schemaFaker->fake($schema);
        AssertApi::assertResponse($schema, $data);
    }
    
    
    public function testCreatesDataArrayFromSchemaListModel() : void
    {
        $properties = Properties::create();
        $properties->add(ScalarProperty::create('scalar-property', 'integer'));
        $properties->add(ListProperty::create('list-property', 'string'));
        
        $objectProperties = Properties::create();
        $objectProperties->add(ScalarProperty::create('object-scalar-property', 'boolean'));
        $objectProperties->add(ListProperty::create('object-scalar-list-property', 'double'));
        $properties->add(
            ObjectProperty::create(
                'object-property', $objectProperties, ['object-scalar-property', 'object-scalar-list-property']
            )
        );
        
        $objectListProperties = Properties::create();
        $objectListProperties->add(ScalarProperty::create('object-list-scalar-property', 'string'));
        $objectListProperties->add(ListProperty::create('object-list-list-property', 'integer'));
        $properties->add(
            ObjectListProperty::create(
                'object-list-property', $objectListProperties,
                ['object-list-scalar-property', 'object-list-list-property']
            )
        );
        
        $items  = Schema::create(
            'LightweightProduct', $properties,
            ['scalar-property', 'list-property', 'object-property', 'object-list-property']
        );
        $schema = SchemaList::create('LightweightProductList', $items);
        
        $data = $this->schemaFaker->fake($schema);
        AssertApi::assertResponse($schema, $data);
    }
    
    
    public function testCreatesDataArrayFromSchemaListScalarModel() : void
    {
        $schema = SchemaListScalar::create('category_ids', 'integer');
        
        $data = $this->schemaFaker->fake($schema);
        AssertApi::assertResponse($schema, $data);
    }
}
