<?php
/* --------------------------------------------------------------
 ParametersTest.php 2019-07-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\Parameter;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Parameter\BodyParameter;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Parameter\PathParameter;
use InvalidArgumentException;
use PHPUnit\Framework\TestCase;

class ParametersTest extends TestCase
{
    /**
     * @var Parameters
     */
    private $collection;
    
    
    protected function setUp()
    {
        $this->collection = Parameters::create();
    }
    
    
    public function testAddsNewItemsOnDemand() : void
    {
        $item = $this->createConfiguredMock(Parameter::class, ['name' => 'foo']);
        $this->collection->add($item);
        $this->assertSame(['foo' => $item], $this->collection->items());
    }
    
    
    public function testHasAccessorForBodyParam() : void
    {
        $pathParam = $this->createMock(PathParameter::class);
        $bodyParam = $this->createMock(BodyParameter::class);
        
        $this->collection->add($pathParam);
        $this->collection->add($bodyParam);
        
        $this->assertSame($bodyParam, $this->collection->bodyParam());
    }
    
    
    public function testConsecutiveBodyParamsWillBeRejected() : void
    {
        $this->expectException(InvalidArgumentException::class);
        
        $itemOne = $this->createMock(BodyParameter::class);
        $itemTwo = $this->createMock(BodyParameter::class);
        
        $this->collection->add($itemOne);
        $this->collection->add($itemTwo);
    }
    
    
    public function testBodyParamCanBeNull() : void
    {
        $pathParam = $this->createMock(PathParameter::class);
        
        $this->collection->add($pathParam);
        
        $this->assertNull($this->collection->bodyParam());
    }
}