<?php
/* --------------------------------------------------------------
 DefinitionTest.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model;

use Faker\Factory;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Collection\Properties;
use PHPUnit\Framework\TestCase;

class DefinitionTest extends TestCase
{
    /**
     * @var Definition
     */
    private $definition;
    
    private $faker;
    
    /**
     * @var string
     */
    private $title;
    
    /**
     * @var Properties
     */
    private $properties;
    
    /**
     * @var array
     */
    private $required;
    
    
    protected function setUp()
    {
        $this->faker = Factory::create('de_DE');
        
        $this->title      = $this->faker->word;
        $this->properties = $this->createMock(Properties::class);
        $this->required   = $this->faker->randomElements(['foo', 'bar', 'baz'], random_int(1, 3));
        
        $this->definition = Definition::create($this->title, $this->properties, $this->required);
    }
    
    
    public function testHasTitle()
    {
        $this->assertEquals($this->title, $this->definition->title());
    }
    
    
    public function testHasListOfRequiredPropertyNames() : void
    {
        $this->assertEquals($this->required, $this->definition->required());
    }
    
    
    public function testHasProperties() : void
    {
        $this->assertSame($this->properties, $this->definition->properties());
    }
}