<?php
/* --------------------------------------------------------------
 PropertyListReferenceTest.php 2019-07-04
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model\Reference;

use InvalidArgumentException;
use PHPUnit\Framework\TestCase;

class PropertyListReferenceTest extends TestCase
{
    
    public function testHoldsReferenceToSchemaFile() : void
    {
        $reference = '#/definitions/GXCategory';
        $data      = [
            'type'  => 'array',
            'items' => [
                '$ref' => $reference
            ]
        ];
        $schema    = PropertyListReference::fromArray($data);
        $this->assertEquals($reference, $schema->reference());
    }
    
    
    public function testRejectsInvalidData()
    {
        $reference = '#/definitions/GXCategory';
        $this->expectException(InvalidArgumentException::class);
        PropertyListReference::fromArray(
            [
                '$ref' => $reference
            ]
        );
    }
    
    
    public function testRejectsInvalidReference()
    {
        $this->expectException(InvalidArgumentException::class);
        PropertyListReference::fromArray(
            [
                'type'  => 'array',
                'items' => [
                    '$ref' => 'invalid'
                ]
            ]
        );
    }
}