<?php
/* --------------------------------------------------------------
 ResponseTest.php 2019-07-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Model;

use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\SchemaReference;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class ResponseTest extends TestCase
{
    public const EXPECTED_STATUS_CODE = 200;
    
    /**
     * @var Response
     */
    private $response;
    
    /**
     * @var MockObject|SchemaReference
     */
    private $reference;
    
    
    protected function setUp()
    {
        $this->reference = $this->createMock(SchemaReference::class);
        $this->response  = Response::create(self::EXPECTED_STATUS_CODE, $this->reference);
    }
    
    
    public function testHasStatusCode() : void
    {
        $this->assertEquals(self::EXPECTED_STATUS_CODE, $this->response->statusCode());
    }
    
    
    public function testHasReferenceToSchema() : void
    {
        $this->assertEquals($this->reference, $this->response->reference());
    }
    
    
    public function testCanBeCheckedForStatusCodeBetweenToCodes() : void
    {
        $errors = [];
        
        $response = Response::create(mt_rand(200, 300), $this->reference);
        if (!$response->statusCodeBetween(200, 300)) {
            $errors[] = "Failed asserting that response status code is between 200 and 300 (current: {$response->statusCode()}).";
        }
        
        $response = Response::create(mt_rand(301, 400), $this->reference);
        if ($response->statusCodeBetween(200, 300)) {
            $errors[] = "Failed asserting that response status code is not between 200 and 300 (current: {$response->statusCode()}).";
        }
        
        $this->assertCount(0, $errors, implode(PHP_EOL, $errors));
    }
}