<?php
/* --------------------------------------------------------------
 ReferenceParserTest.php 2019-08-06
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Resolver;

use Faker\Factory;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\Reference;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Symfony\Component\Yaml\Parser;

class ReferenceParserTest extends TestCase
{
    /**
     * @var ReferenceParser
     */
    private $parser;
    
    /**
     * @var MockObject|ReferenceResolver
     */
    private $resolver;
    
    /**
     * @var MockObject|Parser
     */
    private $yamlParser;
    
    /**
     * @var MockObject|Reference
     */
    private $reference;
    
    
    protected function setUp()
    {
        $this->resolver   = $this->createMock(ReferenceResolver::class);
        $this->yamlParser = $this->createMock(Parser::class);
        
        $this->parser    = new ReferenceParser($this->resolver, $this->yamlParser);
        $this->reference = $this->createMock(Reference::class);
        
        $key   = random_int(1, 2) === 1 ? 'Category' : 'Product';
        $inner = [
            'type' => 'string'
        ];
        
        $data = [
            $key => $inner
        ];
        $this->yamlParser->method('parseFile')->willReturn($data);
    }
    
    
    public function testDelegatesToResolveFilePathOfReference() : void
    {
        $this->resolver->expects($this->once())->method('resolve')->with($this->equalTo($this->reference));
        
        $this->parser->parse($this->reference);
    }
    
    
    public function testDelegatesToParseResolvedFilePath() : void
    {
        $file = Factory::create('de_DE')->word;
        $this->resolver->method('resolve')->willReturn($file);
        $this->yamlParser->expects($this->once())->method('parseFile');
        
        $this->parser->parse($this->reference);
    }
    
    
    public function testReturnsInnerContentOfParsedFile() : void
    {
        $inner = [
            'type' => 'string'
        ];
        
        $this->assertEquals($inner, $this->parser->parse($this->reference));
    }
}
