<?php
/* --------------------------------------------------------------
 RequiredValidatorTest.php 2019-08-15
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\ApiTesting\SwaggerLike\Validator\Schema;

use Gambio\Dragger\ApiTesting\SwaggerLike\Failure\Failures;
use Gambio\Dragger\ApiTesting\SwaggerLike\Model\Contracts\HasRequired;
use PHPUnit\Framework\TestCase;
use function implode;

class RequiredValidatorTest extends TestCase
{
    /**
     * @var RequiredValidator
     */
    private $validator;
    
    /**
     * @var Failures
     */
    private $failures;
    
    
    protected function setUp()
    {
        $this->failures  = Failures::create();
        $this->validator = new RequiredValidator($this->failures);
    }
    
    
    public function testValidatesRequiredPropertiesOfResponseItem() : void
    {
        $required    = $this->required(['foo' => 'bar']);
        $validItem   = ['foo' => 1, 'bar' => 2, 'baz' => 3];
        $invalidItem = ['foo' => 1, 'baz' => 3];
        
        $errors = [];
        if (!$this->validator->validate($required, $validItem)) {
            $errors[] = 'Failed asserting validation succeed with valid item.';
        }
        if ($this->validator->validate($required, $invalidItem)) {
            $errors[] = 'Failed asserting validation fails with invalid item.';
        }
        $this->assertCount(0, $errors, implode(PHP_EOL, $errors));
    }
    
    
    public function testValidatesAddsNewFailuresIntoCollectionOnError() : void
    {
        $required    = $this->required(['foo' => 'bar']);
        $invalidItem = ['foo' => 1, 'baz' => 3];
        $this->validator->validate($required, $invalidItem);
        
        $this->assertGreaterThan(0, $this->failures->count());
    }
    
    
    private function required(array $required) : HasRequired
    {
        /** @noinspection PhpIncompatibleReturnTypeInspection */
        return $this->createConfiguredMock(HasRequired::class, ['required' => $required]);
    }
}
