<?php
/* --------------------------------------------------------------
 TableDataProcessorTest.php 2020-04-30
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\DatabaseFixture\Processor;

use PHPUnit\Framework\TestCase;

class TableDataProcessorTest extends TestCase
{
    public const EXPECTED_CONTENT = <<<'EXPECTED'
return [
    'foo' => [
        [
            'id' => '1',
            'foo_col' => 'First_foo'
        ],
        [
            'id' => '2',
            'foo_col' => 'Second_foo'
        ]
    ],
    'bar' => [
        [
            'id' => '1',
            'bar_col' => 'First_bar'
        ],
        [
            'id' => '2',
            'bar_col' => 'Second_bar'
        ]
    ]
];
EXPECTED;
    
    /**
     * @var TableDataProcessor
     */
    private $processor;
    
    
    protected function setUp(): void
    {
        $this->processor = new TableDataProcessor();
    }
    
    
    public function testCreatesFixtureContentString(): void
    {
        $expected = self::EXPECTED_CONTENT;
        $actual   = $this->processor->createContent(
            [
                'foo' => [
                    [
                        'id'      => '1',
                        'foo_col' => 'First_foo'
                    ],
                    [
                        'id'      => '2',
                        'foo_col' => 'Second_foo'
                    ]
                ],
                'bar' => [
                    [
                        'id'      => '1',
                        'bar_col' => 'First_bar'
                    ],
                    [
                        'id'      => '2',
                        'bar_col' => 'Second_bar'
                    ]
                ]
            ]
        );
        
        $expected = str_replace("\r\n", "\n", $expected);
        $actual   = str_replace("\r\n", "\n", $actual);
        
        $this->assertEquals($expected, $actual);
    }
}
