<?php
/* --------------------------------------------------------------
 PackageFactoryTest.php 2020-04-28
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\PackageComparator\Factories;

use Gambio\Dragger\PackageComparator\Model\Collections\Directories;
use Gambio\Dragger\PackageComparator\Model\Collections\Files;
use Gambio\Dragger\PackageComparator\Model\ComparePackage;
use Gambio\Dragger\PackageComparator\Model\Directory;
use Gambio\Dragger\PackageComparator\Model\File;
use PHPUnit\Framework\TestCase;

class PackageFactoryTest extends TestCase
{
    /**
     * @dataProvider packageFactoryDataProvider
     *
     * @param string $expected
     * @param string $method
     * @param array  $args
     */
    public function testIsResponsibleToCreateDomainModels(string $expected, string $method, array $args): void
    {
        $factory = new PackageFactory();
        
        $this->assertInstanceOf($expected, $factory->{$method}(...$args));
    }
    
    
    public function packageFactoryDataProvider(): array
    {
        return [
            [Directory::class, 'createDirectory', ['', '', '', Directories::create(), Files::create()]],
            [Directories::class, 'createDirectories', []],
            [File::class, 'createFile', ['', '', '']],
            [Files::class, 'createFiles', []],
            [ComparePackage::class, 'createComparePackage', ['', $this->createMock(Directory::class)]],
        ];
    }
}