<?php
/* --------------------------------------------------------------
 DirectoryTest.php 2020-04-24
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\PackageComparator\Model;

use Gambio\Dragger\PackageComparator\Model\Collections\Directories;
use Gambio\Dragger\PackageComparator\Model\Collections\Files;
use PHPUnit\Framework\TestCase;

class DirectoryTest extends TestCase
{
    /**
     * @var Directory
     */
    private $directory;
    
    /**
     * @var string
     */
    private $name;
    
    /**
     * @var string
     */
    private $relative;
    
    /**
     * @var string
     */
    private $absolute;
    
    /**
     * @var Directories
     */
    private $directories;
    
    /**
     * @var Files
     */
    private $files;
    
    
    protected function setUp(): void
    {
        $this->setupTestData();
        $this->directory = $this->createTestDirectory();
    }
    
    
    public function testHasAccessorForName(): void
    {
        $this->assertSame($this->name, $this->directory->name());
    }
    
    
    public function testHasAccessorForRelativePath(): void
    {
        $this->assertSame($this->relative, $this->directory->relativePath());
    }
    
    
    public function testHasAccessorForAbsolutePath(): void
    {
        $this->assertSame($this->absolute, $this->directory->absolutePath());
    }
    
    
    public function testHasAccessorForDirectories(): void
    {
        $this->assertSame($this->directories, $this->directory->directories());
    }
    
    
    public function testHasAccessorForFiles(): void
    {
        $this->assertSame($this->files, $this->directory->files());
    }
    
    
    public function testFindsItselfIfRelativePathsEquals(): void
    {
        $new = $this->createTestDirectory();
        
        $this->assertSame($this->directory, $this->directory->findDirectory($new));
    }
    
    
    public function testFindsNothingIfThereIsNoMatchingSubdirectory(): void
    {
        $this->relative = 'foo-bar';
        $new            = $this->createTestDirectory();
        
        $this->assertNull($this->directory->findDirectory($new));
    }
    
    
    public function testFindsSubdirectoryWithMatchingRelativePath(): void
    {
        $path = './foo/bar';
        
        $expected = Directory::create('', '', $path, Directories::create(), Files::create());
        $this->directories->add($expected);
        $this->directory = $this->createTestDirectory();
        
        $this->setupTestData();
        $this->relative = $path;
        $new            = $this->createTestDirectory();
        
        $this->assertSame($expected, $this->directory->findDirectory($new));
    }
    
    
    private function createTestDirectory(): Directory
    {
        return Directory::create(
            $this->name,
            $this->absolute,
            $this->relative,
            $this->directories,
            $this->files
        );
    }
    
    
    private function setupTestData(): void
    {
        $this->name        = 'name';
        $this->relative    = 'relative';
        $this->absolute    = 'absolute';
        $this->directories = $this->directories ?? Directories::create();
        $this->files       = $this->files ?? Files::create();
    }
}