<?php
/* --------------------------------------------------------------
 AsdProcessorTest.php 2020-04-30
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\PackageComparator\Processors;

use Gambio\Dragger\PackageComparator\Model\ComparePackage;
use Gambio\Dragger\PackageComparator\Utility\DirectoryReader;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class DiffVerifyProcessorTest extends TestCase
{
    /**
     * @var DiffVerifyProcessor
     */
    private $processor;
    
    /**
     * @var DirectoryReader|MockObject
     */
    private $reader;
    
    
    public function setUp(): void
    {
        $this->processor = new DiffVerifyProcessor($this->reader = $this->createMock(DirectoryReader::class));
    }
    
    
    public function testRemovesEntriesFromDifferencesIfTheyAreInSourcePackage(): void
    {
        $differences = [
            './foo/bar/baz/*',
            './foo/baz/*',
            './some/file.php',
            './some/other-file.php'
        ];
        $sourceFiles = [
            './one/two/three/one.php',
            './one/two/three/two.php',
            './one/two/three/three.php',
            './foo/baz/bar.php',
            './some/other-file.php'
        ];
        $expected    = [
            './foo/bar/baz/*',
            './some/file.php',
        ];
        
        $this->reader->method('relativeFilePaths')->willReturn($sourceFiles);
        $sourcePackage = $this->createMock(ComparePackage::class);
        $this->processor->process($sourcePackage, $differences);
        
        $this->assertEquals($expected, $differences);
    }
    
    
    public function testKeepsDifferencesAtItIsIfThereAreNoDifferences(): void
    {
        $differences = [
            './foo/bar/baz/*',
            './foo/baz/*',
            './some/file.php',
            './some/other-file.php'
        ];
        $sourceFiles = [
            './one/two/three/one.php',
            './one/two/three/two.php',
            './one/two/three/three.php',
        ];
        $expected    = [
            './foo/bar/baz/*',
            './foo/baz/*',
            './some/file.php',
            './some/other-file.php'
        ];
        
        $this->reader->method('relativeFilePaths')->willReturn($sourceFiles);
        $sourcePackage = $this->createMock(ComparePackage::class);
        $this->processor->process($sourcePackage, $differences);
        
        $this->assertEquals($expected, $differences);
    }
}