<?php
/* --------------------------------------------------------------
 PackageRepositoryTest.php 2020-04-21
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\PackageComparator\Repositories;

use Gambio\Dragger\PackageComparator\Exceptions\PathNotFoundException;
use Gambio\Dragger\PackageComparator\Factories\PackageFactory;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class PackageRepositoryTest extends TestCase
{
    /**
     * @var PackageRepository
     */
    private $repository;
    
    /**
     * @var PackageFactory|MockObject
     */
    private $factory;
    
    
    protected function setUp(): void
    {
        $this->repository = new PackageRepository($this->factory = $this->createMock(PackageFactory::class));
    }
    
    
    public function testUsesFactoryToCreateTheDirectories(): void
    {
        $arguments = [
            [$this->equalTo('a')],
            [$this->equalTo('c')],
            [$this->equalTo('b')],
            [$this->equalTo('fixtures')],
        ];
        $this->factory->expects($this->exactly(4))->method('createDirectory')->withConsecutive(...$arguments);
        
        $this->repository->getComparePackage('test', __DIR__ . '/fixtures', ['./excluded']);
    }
    
    
    public function testUsesFactoryToCreateFiles(): void
    {
        $arguments = [
            [$this->equalTo('foo_a.php')],
            [$this->equalTo('bar_a.php')],
            [$this->equalTo('baz_b.php')],
            [$this->equalTo('foo_b.php')],
            [$this->equalTo('bar_c.php')],
            [$this->equalTo('foo_c.php')],
            [$this->equalTo('bar_b.php')],
        ];
        $this->factory->expects($this->exactly(7))->method('createFile')->withConsecutive(...$arguments);
        
        $this->repository->getComparePackage('test', __DIR__ . '/fixtures', ['./excluded']);
    }
    
    
    public function testThrowsExceptionIfInvalidPathWasProvided(): void
    {
        $this->expectException(PathNotFoundException::class);
        $this->repository->getComparePackage('test', 'invalid');
    }
}